# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        Account,
        ActivateUserResponse,
        AddOnComponentSource,
        AddonComponent,
        AddonComponentName,
        AddonComponentStatus,
        Ai21Integrations,
        Ai21KeyAuth,
        Ai21Model,
        Ai21ProviderAccount,
        AiFeaturesSettings,
        Alert,
        AlertConfig,
        AlertConfigResource,
        AlertConfigResourceType,
        AlertSeverity,
        AlertStatus,
        AmqpInputConfig,
        AmqpMetricConfig,
        AmqpOutputConfig,
        AnthropicIntegrations,
        AnthropicKeyAuth,
        AnthropicModel,
        AnthropicProviderAccount,
        Application,
        ApplicationDebugInfo,
        ApplicationLifecycleStage,
        ApplicationMetadata,
        ApplicationProblem,
        ApplicationSet,
        ApplicationSetComponentsItem,
        ApplicationType,
        ApplyMlEntityResponse,
        ApplyMlEntityResponseData,
        Artifact,
        ArtifactManifest,
        ArtifactManifestSource,
        ArtifactPath,
        ArtifactType,
        ArtifactVersion,
        ArtifactsCacheVolume,
        ArtifactsDownload,
        ArtifactsDownloadArtifactsItem,
        AssistantMessage,
        AssistantMessageContent,
        AssistantMessageContentOneItem,
        AsyncProcessorSidecar,
        AsyncService,
        AsyncServiceAutoscaling,
        AsyncServiceAutoscalingMetrics,
        AsyncServiceReplicas,
        AutoRotate,
        Autoshutdown,
        AwsAccessKeyAuth,
        AwsAccessKeyBasedAuth,
        AwsAssumedRoleBasedAuth,
        AwsBedrockAssumedRoleBasedAuth,
        AwsBedrockGuardrailConfig,
        AwsBedrockGuardrailConfigAuthData,
        AwsBedrockGuardrailConfigOperation,
        AwsBedrockProviderAccount,
        AwsBedrockProviderAccountAuthData,
        AwsEcr,
        AwsEcrAuthData,
        AwsEksIntegration,
        AwsEksIntegrationAuthData,
        AwsInferentia,
        AwsIntegrations,
        AwsParameterStore,
        AwsParameterStoreAuthData,
        AwsProviderAccount,
        AwsProviderAccountAuthData,
        AwsRegion,
        AwsS3,
        AwsS3AuthData,
        AwsSagemakerProviderAccount,
        AwsSagemakerProviderAccountAuthData,
        AwsSecretsManager,
        AwsSecretsManagerAuthData,
        AwsSqsAccessKeyBasedAuth,
        AwsSqsAssumedRoleBasedAuth,
        AzureAksIntegration,
        AzureBasicAuth,
        AzureBlobStorage,
        AzureConnectionStringAuth,
        AzureContainerRegistry,
        AzureContentSafetyCategory,
        AzureContentSafetyGuardrailConfig,
        AzureFoundryModel,
        AzureFoundryProviderAccount,
        AzureIntegrations,
        AzureKeyAuth,
        AzureOAuth,
        AzureOpenAiModel,
        AzureOpenAiProviderAccount,
        AzurePiiCategory,
        AzurePiiGuardrailConfig,
        AzurePiiGuardrailConfigDomain,
        AzureProviderAccount,
        AzureReposIntegration,
        AzureVault,
        BaseArtifactVersion,
        BaseArtifactVersionManifest,
        BaseAutoscaling,
        BaseOAuth2Login,
        BaseOAuth2LoginJwtSource,
        BaseService,
        BaseServiceImage,
        BaseServiceMountsItem,
        BaseWorkbenchInput,
        BaseWorkbenchInputMountsItem,
        BasicAuthCreds,
        BedrockModel,
        BitbucketIntegration,
        BitbucketProviderAccount,
        BlobStorageReference,
        BlueGreen,
        BudgetAlert,
        BudgetConfig,
        BudgetLimitUnit,
        BudgetRule,
        BudgetWhen,
        Build,
        BuildBuildSource,
        BuildBuildSpec,
        BuildInfo,
        BuildStatus,
        Canary,
        CanaryStep,
        CerebrasIntegrations,
        CerebrasKeyAuth,
        CerebrasModel,
        CerebrasProviderAccount,
        ChangePasswordResponse,
        ChatPromptManifest,
        ChatPromptManifestMcpServersItem,
        ChatPromptManifestMessagesItem,
        ChatPromptManifestResponseFormat,
        ChatPromptManifestRoutingConfig,
        ClouderaIntegrations,
        ClouderaModel,
        ClouderaProviderAccount,
        ClouderaProviderAccountAuthData,
        ClouderaTokenAuth,
        ClouderaWorkloadAuthToken,
        Cluster,
        ClusterGateway,
        ClusterManifest,
        ClusterManifestClusterType,
        ClusterManifestMonitoring,
        ClusterManifestNodeLabelKeys,
        ClusterManifestWorkbenchConfig,
        ClusterType,
        Codeserver,
        CohereIntegrations,
        CohereKeyAuth,
        CohereModel,
        CohereProviderAccount,
        Collaborator,
        CommonToolsSettings,
        Config,
        ContainerTaskConfig,
        ContainerTaskConfigImage,
        ContainerTaskConfigMountsItem,
        CoreNatsOutputConfig,
        CpuUtilizationMetric,
        CreateMultiPartUploadRequest,
        CreatePersonalAccessTokenResponse,
        CronMetric,
        CustomBasicAuth,
        CustomBearerAuth,
        CustomBlobStorage,
        CustomGuardrailConfig,
        CustomGuardrailConfigAuthData,
        CustomGuardrailConfigOperation,
        CustomGuardrailConfigTarget,
        CustomHelmRepo,
        CustomIntegrations,
        CustomJwtAuthIntegration,
        CustomProviderAccount,
        CustomTlsSettings,
        CustomUsernamePasswordArtifactsRegistry,
        DataDirectory,
        DataDirectoryManifest,
        DataDirectoryManifestSource,
        DatabricksApiKeyAuth,
        DatabricksIntegrations,
        DatabricksModel,
        DatabricksProviderAccount,
        DatabricksProviderAccountAuthData,
        DatabricksServicePrincipalAuth,
        DeactivateUserResponse,
        DeepinfraIntegrations,
        DeepinfraKeyAuth,
        DeepinfraModel,
        DeepinfraProviderAccount,
        DeleteApplicationResponse,
        DeleteJobRunResponse,
        DeletePersonalAccessTokenResponse,
        DeleteSecretGroupResponse,
        DeleteTeamResponse,
        DeleteUserResponse,
        DeleteVirtualAccountResponse,
        Deployment,
        DeploymentBuild,
        DeploymentManifest,
        DeploymentStatus,
        DeploymentStatusValue,
        DeploymentTransition,
        DeveloperMessage,
        DeveloperMessageContent,
        DockerFileBuild,
        DockerFileBuildCommand,
        DockerhubBasicAuth,
        DockerhubIntegrations,
        DockerhubProviderAccount,
        DockerhubRegistry,
        DynamicVolumeConfig,
        Email,
        EmailNotificationChannel,
        EmptyResponse,
        Endpoint,
        EnkryptAiGuardrailConfig,
        EnkryptAiGuardrailConfigOperation,
        EnkryptAiKeyAuth,
        Environment,
        EnvironmentColor,
        EnvironmentManifest,
        EnvironmentOptimizeFor,
        Event,
        EventChart,
        EventChartCategory,
        EventInvolvedObject,
        ExternalBlobStorageSource,
        FastAiFramework,
        FiddlerGuardType,
        FiddlerGuardrailConfig,
        FiddlerKeyAuth,
        FileInfo,
        FlyteLaunchPlan,
        FlyteLaunchPlanId,
        FlyteLaunchPlanSpec,
        FlyteTask,
        FlyteTaskCustom,
        FlyteTaskCustomTruefoundry,
        FlyteTaskId,
        FlyteTaskTemplate,
        FlyteWorkflow,
        FlyteWorkflowId,
        FlyteWorkflowTemplate,
        ForwardAction,
        Function,
        FunctionSchema,
        GatewayConfig,
        GatewayConfiguration,
        GatewayOtelConfig,
        GatewayOtelConfigOtelTracesExporterConfig,
        GatewayRequestMetadataFilter,
        GatewayRequestMetadataFilterOperator,
        GatewayRequestMetadataFilterValue,
        GcpApiKeyAuth,
        GcpGcr,
        GcpGcs,
        GcpGkeIntegration,
        GcpGsm,
        GcpIntegrations,
        GcpKeyFileAuth,
        GcpProviderAccount,
        GcpRegion,
        GcpTpu,
        GeminiModel,
        GetAlertsResponse,
        GetApplicationDeploymentResponse,
        GetApplicationResponse,
        GetArtifactResponse,
        GetArtifactVersionResponse,
        GetAuthenticatedVcsurlResponse,
        GetAutoProvisioningStateResponse,
        GetChartsResponse,
        GetClusterResponse,
        GetDataDirectoryResponse,
        GetEnvironmentResponse,
        GetEventsResponse,
        GetJobRunResponse,
        GetLogsResponse,
        GetMlRepoResponse,
        GetModelResponse,
        GetModelVersionResponse,
        GetOrCreatePersonalAccessTokenResponse,
        GetPromptResponse,
        GetPromptVersionResponse,
        GetSecretGroupResponse,
        GetSecretResponse,
        GetSignedUrLsRequest,
        GetSignedUrLsResponse,
        GetSuggestedDeploymentEndpointResponse,
        GetTeamResponse,
        GetTokenForVirtualAccountResponse,
        GetUserResourcesResponse,
        GetUserResponse,
        GetUserTeamsResponse,
        GetVirtualAccountResponse,
        GetWorkspaceResponse,
        GitHelmRepo,
        GitRepositoryExistsResponse,
        GitSource,
        GithubIntegration,
        GithubProviderAccount,
        GitlabIntegration,
        GitlabProviderAccount,
        GluonFramework,
        GoogleGeminiProviderAccount,
        GoogleVertexProviderAccount,
        Graph,
        GraphChartType,
        GroqIntegrations,
        GroqKeyAuth,
        GroqModel,
        GroqProviderAccount,
        GuardrailConfigGroup,
        GuardrailConfigIntegrations,
        Guardrails,
        GuardrailsConfig,
        GuardrailsRule,
        GuardrailsWhen,
        H2OFramework,
        HashicorpIntegrations,
        HashicorpProviderAccount,
        HashicorpTokenAuth,
        HashicorpVaultIntegration,
        HeaderMatch,
        HeaderRoutingConfig,
        HealthProbe,
        Helm,
        HelmRepo,
        HelmSource,
        HttpError,
        HttpErrorCode,
        HttpProbe,
        HttpValidationError,
        HuggingfaceArtifactSource,
        IChange,
        IChangeOperation,
        Image,
        ImageCommand,
        ImageContentPart,
        ImageContentPartImageUrl,
        ImageContentPartImageUrlUrl,
        InferMethodName,
        InfraProviderAccount,
        IngressControllerConfig,
        InputOutputBasedCostMetricValue,
        Intercept,
        InterceptRulesItem,
        InterceptRulesItemAction,
        InternalArtifactVersion,
        InternalListArtifactVersionsResponse,
        InternalListArtifactVersionsResponseDataItem,
        InternalModelVersion,
        InviteUserResponse,
        IsClusterConnectedResponse,
        JFrogIntegrations,
        JfrogArtifactsRegistry,
        JfrogBasicAuth,
        JfrogProviderAccount,
        Job,
        JobAlert,
        JobImage,
        JobMountsItem,
        JobRun,
        JobRunStatus,
        JobRunsSortBy,
        JobTrigger,
        JobTriggerInput,
        JobTriggerInputCommand,
        JsonObjectResponseFormat,
        JsonSchema,
        JsonSchemaResponseFormat,
        Jwt,
        JwtAuthConfig,
        JwtAuthConfigClaimsItem,
        KafkaInputConfig,
        KafkaMetricConfig,
        KafkaOutputConfig,
        KafkaSaslAuth,
        KerasFramework,
        Kustomize,
        LatencyBasedLoadBalanceTarget,
        LatencyBasedLoadBalancing,
        LatencyBasedLoadBalancingRule,
        LibraryName,
        LightGbmFramework,
        ListApplicationDeploymentsResponse,
        ListApplicationsResponse,
        ListArtifactVersionsResponse,
        ListArtifactsResponse,
        ListClusterAddonsResponse,
        ListClustersResponse,
        ListDataDirectoriesResponse,
        ListEnvironmentsResponse,
        ListFilesRequest,
        ListFilesResponse,
        ListJobRunResponse,
        ListMlReposResponse,
        ListModelVersionsResponse,
        ListModelsResponse,
        ListPersonalAccessTokenResponse,
        ListPromptVersionsResponse,
        ListPromptsResponse,
        ListSecretGroupResponse,
        ListSecretsResponse,
        ListTeamsResponse,
        ListUsersResponse,
        ListVirtualAccountResponse,
        ListWorkspacesResponse,
        LoadBalanceTarget,
        LoadBalancingConfig,
        LoadBalancingRule,
        LoadBalancingWhen,
        LocalArtifactSource,
        LocalModelSource,
        LocalSource,
        Log,
        LogsFilterQuery,
        LogsFilterQueryType,
        LogsResponse,
        LogsSearchFilterType,
        LogsSearchOperatorType,
        LogsSortingDirection,
        Manual,
        McpServerAuth,
        McpServerHeaderAuth,
        McpServerHeaderOverrideAuth,
        McpServerIntegration,
        McpServerIntegrationTransport,
        McpServerIntegrations,
        McpServerOAuth2,
        McpServerOAuth2JwtSource,
        McpServerPassthrough,
        McpServerProviderAccount,
        McpServerToolDetails,
        McpServerWithFqn,
        McpServerWithUrl,
        McpTool,
        Metadata,
        Metric,
        MimeType,
        MirrorAction,
        MistralAiIntegrations,
        MistralAiKeyAuth,
        MistralAiModel,
        MistralAiProviderAccount,
        MlRepo,
        MlRepoManifest,
        Model,
        ModelConfiguration,
        ModelCostMetric,
        ModelManifest,
        ModelManifestFramework,
        ModelManifestSource,
        ModelProviderAccount,
        ModelType,
        ModelVersion,
        ModelVersionEnvironment,
        MultiPartUpload,
        MultiPartUploadResponse,
        MultiPartUploadStorageProvider,
        NatsInputConfig,
        NatsMetricConfig,
        NatsOutputConfig,
        NatsUserPasswordAuth,
        NodeSelector,
        NodeSelectorCapacityType,
        Nodepool,
        NodepoolSelector,
        NomicIntegrations,
        NomicKeyAuth,
        NomicModel,
        NomicProviderAccount,
        NonNegativeFloat,
        Notebook,
        NotebookConfig,
        NotificationTarget,
        NotificationTargetForAlertRule,
        NvidiaGpu,
        NvidiaMiggpu,
        NvidiaMiggpuProfile,
        NvidiaTimeslicingGpu,
        OAuth2LoginProvider,
        OciRepo,
        OllamaIntegrations,
        OllamaKeyAuth,
        OllamaModel,
        OllamaProviderAccount,
        OnnxFramework,
        OpenAiIntegrations,
        OpenAiModel,
        OpenAiModerationsGuardrailConfig,
        OpenAiModerationsGuardrailConfigCategoryThresholdsValue,
        OpenAiModerationsGuardrailConfigCategoryThresholdsValueHarassment,
        OpenRouterApiKeyAuth,
        OpenRouterIntegrations,
        OpenRouterModel,
        OpenRouterProviderAccount,
        OpenaiApiKeyAuth,
        OpenaiProviderAccount,
        Operation,
        OtelExporterGrpcConfig,
        OtelExporterHttpConfig,
        OtelExporterHttpConfigEncoding,
        OwnedBy,
        PaddleFramework,
        PagerDuty,
        PagerDutyIntegration,
        PagerDutyIntegrationKeyAuth,
        PagerDutyIntegrations,
        PagerDutyProviderAccount,
        Pagination,
        PalmIntegrations,
        PalmKeyAuth,
        PalmModel,
        PalmProviderAccount,
        PaloAltoPrismaAirsGuardrailConfig,
        PaloAltoPrismaAirsGuardrailConfigMode,
        PaloAltoPrismaAirsKeyAuth,
        PangeaGuardType,
        PangeaGuardrailConfig,
        PangeaGuardrailConfigOperation,
        PangeaKeyAuth,
        Param,
        ParamParamType,
        Parameters,
        ParametersStop,
        PatronusAnswerRelevanceCriteria,
        PatronusAnswerRelevanceEvaluator,
        PatronusEvaluator,
        PatronusGliderCriteria,
        PatronusGliderEvaluator,
        PatronusGuardrailConfig,
        PatronusGuardrailConfigTarget,
        PatronusJudgeCriteria,
        PatronusJudgeEvaluator,
        PatronusKeyAuth,
        PatronusPhiCriteria,
        PatronusPhiEvaluator,
        PatronusPiiCriteria,
        PatronusPiiEvaluator,
        PatronusToxicityCriteria,
        PatronusToxicityEvaluator,
        PerThousandEmbeddingTokensCostMetric,
        PerThousandTokensCostMetric,
        Permissions,
        PerplexityAiKeyAuth,
        PerplexityAiModel,
        PerplexityAiProviderAccount,
        PerplexityIntegrations,
        PersonalAccessTokenManifest,
        Pip,
        Poetry,
        PolicyActions,
        PolicyEntityTypes,
        PolicyFilters,
        PolicyManifest,
        PolicyManifestMode,
        PolicyManifestOperation,
        PolicyMutationOperation,
        PolicyValidationOperation,
        Port,
        PortAppProtocol,
        PortAuth,
        PortProtocol,
        PresignedUrlObject,
        PriorityBasedLoadBalanceTarget,
        PriorityBasedLoadBalancing,
        PriorityBasedLoadBalancingRule,
        PrometheusAlertRule,
        Prompt,
        PromptFooGuardType,
        PromptFooGuardrailConfig,
        PromptFooGuardrailConfigOperation,
        PromptVersion,
        ProviderAccounts,
        PublicCostMetric,
        PySparkTaskConfig,
        PyTorchFramework,
        PythonBuild,
        PythonBuildCommand,
        PythonBuildPythonDependencies,
        PythonTaskConfig,
        PythonTaskConfigImage,
        PythonTaskConfigMountsItem,
        QuayArtifactsRegistry,
        QuayBasicAuth,
        QuayIntegrations,
        QuayProviderAccount,
        QuerySpansResponse,
        RStudio,
        RateLimitConfig,
        RateLimitRule,
        RateLimitUnit,
        RateLimitWhen,
        Recommendation,
        RefusalContentPart,
        RegisterUsersResponse,
        RemoteSource,
        Resources,
        ResourcesDevicesItem,
        ResourcesNode,
        RetryConfig,
        RevokeAllPersonalAccessTokenResponse,
        RoleManifest,
        RolePermissions,
        Rolling,
        RpsMetric,
        SagemakerModel,
        SambaNovaIntegrations,
        SambaNovaKeyAuth,
        SambaNovaModel,
        SambaNovaProviderAccount,
        Schedule,
        ScheduleConcurrencyPolicy,
        Secret,
        SecretGroup,
        SecretGroupManifest,
        SecretInput,
        SecretMount,
        SecretStoreConfig,
        SecretVersion,
        SelfHostedModel,
        SelfHostedModelAuthData,
        SelfHostedModelIntegrations,
        SelfHostedModelModelServer,
        SelfHostedModelProviderAccount,
        Service,
        ServiceAutoscaling,
        ServiceAutoscalingMetrics,
        ServiceReplicas,
        ServiceRolloutStrategy,
        Session,
        SignedUrl,
        SklearnFramework,
        SklearnModelSchema,
        SklearnSerializationFormat,
        SlaCutoff,
        SlackBot,
        SlackBotAuth,
        SlackBotIntegration,
        SlackIntegrations,
        SlackProviderAccount,
        SlackWebhook,
        SlackWebhookAuth,
        SlackWebhookIntegration,
        SmtpCredentials,
        SnowflakeCortexIntegrations,
        SnowflakeCortexModel,
        SnowflakeCortexPatTokenAuth,
        SnowflakeCortexProviderAccount,
        SortDirection,
        SpaCyFramework,
        SpanAttributeFilter,
        SpanAttributeFilterOperator,
        SpanAttributeFilterValue,
        SpanFieldFilter,
        SpanFieldFilterOperator,
        SpanFieldFilterSpanFieldName,
        SpanFieldFilterValue,
        SparkBuild,
        SparkConfig,
        SparkDriverConfig,
        SparkExecutorConfig,
        SparkExecutorConfigInstances,
        SparkExecutorDynamicScaling,
        SparkExecutorFixedInstances,
        SparkImage,
        SparkImageBuild,
        SparkImageBuildBuildSource,
        SparkJob,
        SparkJobEntrypoint,
        SparkJobImage,
        SparkJobJavaEntrypoint,
        SparkJobPythonEntrypoint,
        SparkJobPythonNotebookEntrypoint,
        SparkJobScalaEntrypoint,
        SparkJobScalaNotebookEntrypoint,
        SparkJobTriggerInput,
        SqsInputConfig,
        SqsOutputConfig,
        SqsQueueMetricConfig,
        SqsQueueMetricConfigAuth,
        SshServer,
        SshServerConfig,
        SsoTeamManifest,
        StageArtifactResponse,
        StaticVolumeConfig,
        StatsModelsFramework,
        StringDataMount,
        Subject,
        SubjectType,
        SyncTokenInSecretStoreInfo,
        SyncVirtualAccountTokenResponse,
        SystemMessage,
        SystemMessageContent,
        TaskDockerFileBuild,
        TaskPySparkBuild,
        TaskPythonBuild,
        Team,
        TeamManifest,
        TeamOwnedBy,
        TensorFlowFramework,
        TerminateJobResponse,
        TextContentPart,
        TextContentPartText,
        TogetherAiIntegrations,
        TogetherAiKeyAuth,
        TogetherAiModel,
        TogetherAiProviderAccount,
        TokenPagination,
        ToolCall,
        ToolMessage,
        ToolMessageContent,
        ToolSchema,
        TraceSpan,
        TracingProject,
        TracingProjectManifest,
        TransformersFramework,
        TriggerJobRunResponse,
        TrueFoundryApplyRequestManifest,
        TrueFoundryApplyResponse,
        TrueFoundryApplyResponseAction,
        TrueFoundryApplyResponseExistingManifest,
        TrueFoundryArtifactSource,
        TrueFoundryDbssm,
        TrueFoundryDeleteRequestManifest,
        TrueFoundryIntegrations,
        TrueFoundryInteractiveLogin,
        TrueFoundryManagedSource,
        TrueFoundryProviderAccount,
        TtlIntegrations,
        TtlProviderAccount,
        TtlRegistry,
        UpdateSecretInput,
        UpdateUserRolesResponse,
        UpgradeData,
        UsageCodeSnippet,
        User,
        UserMessage,
        UserMessageContent,
        UserMessageContentOneItem,
        UserMetadata,
        UserMetadataTenantRoleManagedBy,
        UserResource,
        UserRoleWithResource,
        UserRoleWithResourceResourceType,
        Uv,
        ValidationError,
        ValidationErrorLocItem,
        VertexModel,
        VirtualAccount,
        VirtualAccountManifest,
        VirtualAccountOwnedBy,
        VirtualMcpServerIntegration,
        VirtualMcpServerSource,
        VirtualModel,
        VirtualModelProviderAccount,
        Volume,
        VolumeBrowser,
        VolumeConfig,
        VolumeMount,
        WebhookBasicAuth,
        WebhookBearerAuth,
        WebhookIntegration,
        WebhookIntegrationAuthData,
        WebhookIntegrations,
        WebhookProviderAccount,
        WeightBasedLoadBalancing,
        WeightBasedLoadBalancingRule,
        WorkbenchImage,
        WorkerConfig,
        WorkerConfigInputConfig,
        WorkerConfigOutputConfig,
        Workflow,
        WorkflowAlert,
        WorkflowFlyteEntitiesItem,
        WorkflowSource,
        Workspace,
        WorkspaceManifest,
        XgBoostFramework,
        XgBoostModelSchema,
        XgBoostSerializationFormat,
    )
    from .errors import (
        BadRequestError,
        ConflictError,
        ExpectationFailedError,
        FailedDependencyError,
        ForbiddenError,
        MethodNotAllowedError,
        NotFoundError,
        NotImplementedError,
        UnauthorizedError,
        UnprocessableEntityError,
    )
    from . import (
        alerts,
        application_versions,
        applications,
        artifact_versions,
        artifacts,
        clusters,
        data_directories,
        environments,
        events,
        internal,
        jobs,
        logs,
        ml_repos,
        model_versions,
        models,
        personal_access_tokens,
        prompt_versions,
        prompts,
        secret_groups,
        secrets,
        teams,
        traces,
        users,
        virtual_accounts,
        workspaces,
    )
    from .applications import (
        ApplicationsCancelDeploymentResponse,
        ApplicationsListRequestDeviceTypeFilter,
        ApplicationsListRequestLifecycleStage,
    )
    from .artifact_versions import StageArtifactRequestManifest
    from .client import AsyncTrueFoundry, TrueFoundry
    from .clusters import ClustersDeleteResponse
    from .jobs import TriggerJobRequestInput
    from .teams import ApplyTeamRequestManifest, TeamsListRequestType
    from .traces import QuerySpansRequestFiltersItem
    from .version import __version__
    from .workspaces import WorkspacesDeleteResponse
_dynamic_imports: typing.Dict[str, str] = {
    "Account": ".types",
    "ActivateUserResponse": ".types",
    "AddOnComponentSource": ".types",
    "AddonComponent": ".types",
    "AddonComponentName": ".types",
    "AddonComponentStatus": ".types",
    "Ai21Integrations": ".types",
    "Ai21KeyAuth": ".types",
    "Ai21Model": ".types",
    "Ai21ProviderAccount": ".types",
    "AiFeaturesSettings": ".types",
    "Alert": ".types",
    "AlertConfig": ".types",
    "AlertConfigResource": ".types",
    "AlertConfigResourceType": ".types",
    "AlertSeverity": ".types",
    "AlertStatus": ".types",
    "AmqpInputConfig": ".types",
    "AmqpMetricConfig": ".types",
    "AmqpOutputConfig": ".types",
    "AnthropicIntegrations": ".types",
    "AnthropicKeyAuth": ".types",
    "AnthropicModel": ".types",
    "AnthropicProviderAccount": ".types",
    "Application": ".types",
    "ApplicationDebugInfo": ".types",
    "ApplicationLifecycleStage": ".types",
    "ApplicationMetadata": ".types",
    "ApplicationProblem": ".types",
    "ApplicationSet": ".types",
    "ApplicationSetComponentsItem": ".types",
    "ApplicationType": ".types",
    "ApplicationsCancelDeploymentResponse": ".applications",
    "ApplicationsListRequestDeviceTypeFilter": ".applications",
    "ApplicationsListRequestLifecycleStage": ".applications",
    "ApplyMlEntityResponse": ".types",
    "ApplyMlEntityResponseData": ".types",
    "ApplyTeamRequestManifest": ".teams",
    "Artifact": ".types",
    "ArtifactManifest": ".types",
    "ArtifactManifestSource": ".types",
    "ArtifactPath": ".types",
    "ArtifactType": ".types",
    "ArtifactVersion": ".types",
    "ArtifactsCacheVolume": ".types",
    "ArtifactsDownload": ".types",
    "ArtifactsDownloadArtifactsItem": ".types",
    "AssistantMessage": ".types",
    "AssistantMessageContent": ".types",
    "AssistantMessageContentOneItem": ".types",
    "AsyncProcessorSidecar": ".types",
    "AsyncService": ".types",
    "AsyncServiceAutoscaling": ".types",
    "AsyncServiceAutoscalingMetrics": ".types",
    "AsyncServiceReplicas": ".types",
    "AsyncTrueFoundry": ".client",
    "AutoRotate": ".types",
    "Autoshutdown": ".types",
    "AwsAccessKeyAuth": ".types",
    "AwsAccessKeyBasedAuth": ".types",
    "AwsAssumedRoleBasedAuth": ".types",
    "AwsBedrockAssumedRoleBasedAuth": ".types",
    "AwsBedrockGuardrailConfig": ".types",
    "AwsBedrockGuardrailConfigAuthData": ".types",
    "AwsBedrockGuardrailConfigOperation": ".types",
    "AwsBedrockProviderAccount": ".types",
    "AwsBedrockProviderAccountAuthData": ".types",
    "AwsEcr": ".types",
    "AwsEcrAuthData": ".types",
    "AwsEksIntegration": ".types",
    "AwsEksIntegrationAuthData": ".types",
    "AwsInferentia": ".types",
    "AwsIntegrations": ".types",
    "AwsParameterStore": ".types",
    "AwsParameterStoreAuthData": ".types",
    "AwsProviderAccount": ".types",
    "AwsProviderAccountAuthData": ".types",
    "AwsRegion": ".types",
    "AwsS3": ".types",
    "AwsS3AuthData": ".types",
    "AwsSagemakerProviderAccount": ".types",
    "AwsSagemakerProviderAccountAuthData": ".types",
    "AwsSecretsManager": ".types",
    "AwsSecretsManagerAuthData": ".types",
    "AwsSqsAccessKeyBasedAuth": ".types",
    "AwsSqsAssumedRoleBasedAuth": ".types",
    "AzureAksIntegration": ".types",
    "AzureBasicAuth": ".types",
    "AzureBlobStorage": ".types",
    "AzureConnectionStringAuth": ".types",
    "AzureContainerRegistry": ".types",
    "AzureContentSafetyCategory": ".types",
    "AzureContentSafetyGuardrailConfig": ".types",
    "AzureFoundryModel": ".types",
    "AzureFoundryProviderAccount": ".types",
    "AzureIntegrations": ".types",
    "AzureKeyAuth": ".types",
    "AzureOAuth": ".types",
    "AzureOpenAiModel": ".types",
    "AzureOpenAiProviderAccount": ".types",
    "AzurePiiCategory": ".types",
    "AzurePiiGuardrailConfig": ".types",
    "AzurePiiGuardrailConfigDomain": ".types",
    "AzureProviderAccount": ".types",
    "AzureReposIntegration": ".types",
    "AzureVault": ".types",
    "BadRequestError": ".errors",
    "BaseArtifactVersion": ".types",
    "BaseArtifactVersionManifest": ".types",
    "BaseAutoscaling": ".types",
    "BaseOAuth2Login": ".types",
    "BaseOAuth2LoginJwtSource": ".types",
    "BaseService": ".types",
    "BaseServiceImage": ".types",
    "BaseServiceMountsItem": ".types",
    "BaseWorkbenchInput": ".types",
    "BaseWorkbenchInputMountsItem": ".types",
    "BasicAuthCreds": ".types",
    "BedrockModel": ".types",
    "BitbucketIntegration": ".types",
    "BitbucketProviderAccount": ".types",
    "BlobStorageReference": ".types",
    "BlueGreen": ".types",
    "BudgetAlert": ".types",
    "BudgetConfig": ".types",
    "BudgetLimitUnit": ".types",
    "BudgetRule": ".types",
    "BudgetWhen": ".types",
    "Build": ".types",
    "BuildBuildSource": ".types",
    "BuildBuildSpec": ".types",
    "BuildInfo": ".types",
    "BuildStatus": ".types",
    "Canary": ".types",
    "CanaryStep": ".types",
    "CerebrasIntegrations": ".types",
    "CerebrasKeyAuth": ".types",
    "CerebrasModel": ".types",
    "CerebrasProviderAccount": ".types",
    "ChangePasswordResponse": ".types",
    "ChatPromptManifest": ".types",
    "ChatPromptManifestMcpServersItem": ".types",
    "ChatPromptManifestMessagesItem": ".types",
    "ChatPromptManifestResponseFormat": ".types",
    "ChatPromptManifestRoutingConfig": ".types",
    "ClouderaIntegrations": ".types",
    "ClouderaModel": ".types",
    "ClouderaProviderAccount": ".types",
    "ClouderaProviderAccountAuthData": ".types",
    "ClouderaTokenAuth": ".types",
    "ClouderaWorkloadAuthToken": ".types",
    "Cluster": ".types",
    "ClusterGateway": ".types",
    "ClusterManifest": ".types",
    "ClusterManifestClusterType": ".types",
    "ClusterManifestMonitoring": ".types",
    "ClusterManifestNodeLabelKeys": ".types",
    "ClusterManifestWorkbenchConfig": ".types",
    "ClusterType": ".types",
    "ClustersDeleteResponse": ".clusters",
    "Codeserver": ".types",
    "CohereIntegrations": ".types",
    "CohereKeyAuth": ".types",
    "CohereModel": ".types",
    "CohereProviderAccount": ".types",
    "Collaborator": ".types",
    "CommonToolsSettings": ".types",
    "Config": ".types",
    "ConflictError": ".errors",
    "ContainerTaskConfig": ".types",
    "ContainerTaskConfigImage": ".types",
    "ContainerTaskConfigMountsItem": ".types",
    "CoreNatsOutputConfig": ".types",
    "CpuUtilizationMetric": ".types",
    "CreateMultiPartUploadRequest": ".types",
    "CreatePersonalAccessTokenResponse": ".types",
    "CronMetric": ".types",
    "CustomBasicAuth": ".types",
    "CustomBearerAuth": ".types",
    "CustomBlobStorage": ".types",
    "CustomGuardrailConfig": ".types",
    "CustomGuardrailConfigAuthData": ".types",
    "CustomGuardrailConfigOperation": ".types",
    "CustomGuardrailConfigTarget": ".types",
    "CustomHelmRepo": ".types",
    "CustomIntegrations": ".types",
    "CustomJwtAuthIntegration": ".types",
    "CustomProviderAccount": ".types",
    "CustomTlsSettings": ".types",
    "CustomUsernamePasswordArtifactsRegistry": ".types",
    "DataDirectory": ".types",
    "DataDirectoryManifest": ".types",
    "DataDirectoryManifestSource": ".types",
    "DatabricksApiKeyAuth": ".types",
    "DatabricksIntegrations": ".types",
    "DatabricksModel": ".types",
    "DatabricksProviderAccount": ".types",
    "DatabricksProviderAccountAuthData": ".types",
    "DatabricksServicePrincipalAuth": ".types",
    "DeactivateUserResponse": ".types",
    "DeepinfraIntegrations": ".types",
    "DeepinfraKeyAuth": ".types",
    "DeepinfraModel": ".types",
    "DeepinfraProviderAccount": ".types",
    "DeleteApplicationResponse": ".types",
    "DeleteJobRunResponse": ".types",
    "DeletePersonalAccessTokenResponse": ".types",
    "DeleteSecretGroupResponse": ".types",
    "DeleteTeamResponse": ".types",
    "DeleteUserResponse": ".types",
    "DeleteVirtualAccountResponse": ".types",
    "Deployment": ".types",
    "DeploymentBuild": ".types",
    "DeploymentManifest": ".types",
    "DeploymentStatus": ".types",
    "DeploymentStatusValue": ".types",
    "DeploymentTransition": ".types",
    "DeveloperMessage": ".types",
    "DeveloperMessageContent": ".types",
    "DockerFileBuild": ".types",
    "DockerFileBuildCommand": ".types",
    "DockerhubBasicAuth": ".types",
    "DockerhubIntegrations": ".types",
    "DockerhubProviderAccount": ".types",
    "DockerhubRegistry": ".types",
    "DynamicVolumeConfig": ".types",
    "Email": ".types",
    "EmailNotificationChannel": ".types",
    "EmptyResponse": ".types",
    "Endpoint": ".types",
    "EnkryptAiGuardrailConfig": ".types",
    "EnkryptAiGuardrailConfigOperation": ".types",
    "EnkryptAiKeyAuth": ".types",
    "Environment": ".types",
    "EnvironmentColor": ".types",
    "EnvironmentManifest": ".types",
    "EnvironmentOptimizeFor": ".types",
    "Event": ".types",
    "EventChart": ".types",
    "EventChartCategory": ".types",
    "EventInvolvedObject": ".types",
    "ExpectationFailedError": ".errors",
    "ExternalBlobStorageSource": ".types",
    "FailedDependencyError": ".errors",
    "FastAiFramework": ".types",
    "FiddlerGuardType": ".types",
    "FiddlerGuardrailConfig": ".types",
    "FiddlerKeyAuth": ".types",
    "FileInfo": ".types",
    "FlyteLaunchPlan": ".types",
    "FlyteLaunchPlanId": ".types",
    "FlyteLaunchPlanSpec": ".types",
    "FlyteTask": ".types",
    "FlyteTaskCustom": ".types",
    "FlyteTaskCustomTruefoundry": ".types",
    "FlyteTaskId": ".types",
    "FlyteTaskTemplate": ".types",
    "FlyteWorkflow": ".types",
    "FlyteWorkflowId": ".types",
    "FlyteWorkflowTemplate": ".types",
    "ForbiddenError": ".errors",
    "ForwardAction": ".types",
    "Function": ".types",
    "FunctionSchema": ".types",
    "GatewayConfig": ".types",
    "GatewayConfiguration": ".types",
    "GatewayOtelConfig": ".types",
    "GatewayOtelConfigOtelTracesExporterConfig": ".types",
    "GatewayRequestMetadataFilter": ".types",
    "GatewayRequestMetadataFilterOperator": ".types",
    "GatewayRequestMetadataFilterValue": ".types",
    "GcpApiKeyAuth": ".types",
    "GcpGcr": ".types",
    "GcpGcs": ".types",
    "GcpGkeIntegration": ".types",
    "GcpGsm": ".types",
    "GcpIntegrations": ".types",
    "GcpKeyFileAuth": ".types",
    "GcpProviderAccount": ".types",
    "GcpRegion": ".types",
    "GcpTpu": ".types",
    "GeminiModel": ".types",
    "GetAlertsResponse": ".types",
    "GetApplicationDeploymentResponse": ".types",
    "GetApplicationResponse": ".types",
    "GetArtifactResponse": ".types",
    "GetArtifactVersionResponse": ".types",
    "GetAuthenticatedVcsurlResponse": ".types",
    "GetAutoProvisioningStateResponse": ".types",
    "GetChartsResponse": ".types",
    "GetClusterResponse": ".types",
    "GetDataDirectoryResponse": ".types",
    "GetEnvironmentResponse": ".types",
    "GetEventsResponse": ".types",
    "GetJobRunResponse": ".types",
    "GetLogsResponse": ".types",
    "GetMlRepoResponse": ".types",
    "GetModelResponse": ".types",
    "GetModelVersionResponse": ".types",
    "GetOrCreatePersonalAccessTokenResponse": ".types",
    "GetPromptResponse": ".types",
    "GetPromptVersionResponse": ".types",
    "GetSecretGroupResponse": ".types",
    "GetSecretResponse": ".types",
    "GetSignedUrLsRequest": ".types",
    "GetSignedUrLsResponse": ".types",
    "GetSuggestedDeploymentEndpointResponse": ".types",
    "GetTeamResponse": ".types",
    "GetTokenForVirtualAccountResponse": ".types",
    "GetUserResourcesResponse": ".types",
    "GetUserResponse": ".types",
    "GetUserTeamsResponse": ".types",
    "GetVirtualAccountResponse": ".types",
    "GetWorkspaceResponse": ".types",
    "GitHelmRepo": ".types",
    "GitRepositoryExistsResponse": ".types",
    "GitSource": ".types",
    "GithubIntegration": ".types",
    "GithubProviderAccount": ".types",
    "GitlabIntegration": ".types",
    "GitlabProviderAccount": ".types",
    "GluonFramework": ".types",
    "GoogleGeminiProviderAccount": ".types",
    "GoogleVertexProviderAccount": ".types",
    "Graph": ".types",
    "GraphChartType": ".types",
    "GroqIntegrations": ".types",
    "GroqKeyAuth": ".types",
    "GroqModel": ".types",
    "GroqProviderAccount": ".types",
    "GuardrailConfigGroup": ".types",
    "GuardrailConfigIntegrations": ".types",
    "Guardrails": ".types",
    "GuardrailsConfig": ".types",
    "GuardrailsRule": ".types",
    "GuardrailsWhen": ".types",
    "H2OFramework": ".types",
    "HashicorpIntegrations": ".types",
    "HashicorpProviderAccount": ".types",
    "HashicorpTokenAuth": ".types",
    "HashicorpVaultIntegration": ".types",
    "HeaderMatch": ".types",
    "HeaderRoutingConfig": ".types",
    "HealthProbe": ".types",
    "Helm": ".types",
    "HelmRepo": ".types",
    "HelmSource": ".types",
    "HttpError": ".types",
    "HttpErrorCode": ".types",
    "HttpProbe": ".types",
    "HttpValidationError": ".types",
    "HuggingfaceArtifactSource": ".types",
    "IChange": ".types",
    "IChangeOperation": ".types",
    "Image": ".types",
    "ImageCommand": ".types",
    "ImageContentPart": ".types",
    "ImageContentPartImageUrl": ".types",
    "ImageContentPartImageUrlUrl": ".types",
    "InferMethodName": ".types",
    "InfraProviderAccount": ".types",
    "IngressControllerConfig": ".types",
    "InputOutputBasedCostMetricValue": ".types",
    "Intercept": ".types",
    "InterceptRulesItem": ".types",
    "InterceptRulesItemAction": ".types",
    "InternalArtifactVersion": ".types",
    "InternalListArtifactVersionsResponse": ".types",
    "InternalListArtifactVersionsResponseDataItem": ".types",
    "InternalModelVersion": ".types",
    "InviteUserResponse": ".types",
    "IsClusterConnectedResponse": ".types",
    "JFrogIntegrations": ".types",
    "JfrogArtifactsRegistry": ".types",
    "JfrogBasicAuth": ".types",
    "JfrogProviderAccount": ".types",
    "Job": ".types",
    "JobAlert": ".types",
    "JobImage": ".types",
    "JobMountsItem": ".types",
    "JobRun": ".types",
    "JobRunStatus": ".types",
    "JobRunsSortBy": ".types",
    "JobTrigger": ".types",
    "JobTriggerInput": ".types",
    "JobTriggerInputCommand": ".types",
    "JsonObjectResponseFormat": ".types",
    "JsonSchema": ".types",
    "JsonSchemaResponseFormat": ".types",
    "Jwt": ".types",
    "JwtAuthConfig": ".types",
    "JwtAuthConfigClaimsItem": ".types",
    "KafkaInputConfig": ".types",
    "KafkaMetricConfig": ".types",
    "KafkaOutputConfig": ".types",
    "KafkaSaslAuth": ".types",
    "KerasFramework": ".types",
    "Kustomize": ".types",
    "LatencyBasedLoadBalanceTarget": ".types",
    "LatencyBasedLoadBalancing": ".types",
    "LatencyBasedLoadBalancingRule": ".types",
    "LibraryName": ".types",
    "LightGbmFramework": ".types",
    "ListApplicationDeploymentsResponse": ".types",
    "ListApplicationsResponse": ".types",
    "ListArtifactVersionsResponse": ".types",
    "ListArtifactsResponse": ".types",
    "ListClusterAddonsResponse": ".types",
    "ListClustersResponse": ".types",
    "ListDataDirectoriesResponse": ".types",
    "ListEnvironmentsResponse": ".types",
    "ListFilesRequest": ".types",
    "ListFilesResponse": ".types",
    "ListJobRunResponse": ".types",
    "ListMlReposResponse": ".types",
    "ListModelVersionsResponse": ".types",
    "ListModelsResponse": ".types",
    "ListPersonalAccessTokenResponse": ".types",
    "ListPromptVersionsResponse": ".types",
    "ListPromptsResponse": ".types",
    "ListSecretGroupResponse": ".types",
    "ListSecretsResponse": ".types",
    "ListTeamsResponse": ".types",
    "ListUsersResponse": ".types",
    "ListVirtualAccountResponse": ".types",
    "ListWorkspacesResponse": ".types",
    "LoadBalanceTarget": ".types",
    "LoadBalancingConfig": ".types",
    "LoadBalancingRule": ".types",
    "LoadBalancingWhen": ".types",
    "LocalArtifactSource": ".types",
    "LocalModelSource": ".types",
    "LocalSource": ".types",
    "Log": ".types",
    "LogsFilterQuery": ".types",
    "LogsFilterQueryType": ".types",
    "LogsResponse": ".types",
    "LogsSearchFilterType": ".types",
    "LogsSearchOperatorType": ".types",
    "LogsSortingDirection": ".types",
    "Manual": ".types",
    "McpServerAuth": ".types",
    "McpServerHeaderAuth": ".types",
    "McpServerHeaderOverrideAuth": ".types",
    "McpServerIntegration": ".types",
    "McpServerIntegrationTransport": ".types",
    "McpServerIntegrations": ".types",
    "McpServerOAuth2": ".types",
    "McpServerOAuth2JwtSource": ".types",
    "McpServerPassthrough": ".types",
    "McpServerProviderAccount": ".types",
    "McpServerToolDetails": ".types",
    "McpServerWithFqn": ".types",
    "McpServerWithUrl": ".types",
    "McpTool": ".types",
    "Metadata": ".types",
    "MethodNotAllowedError": ".errors",
    "Metric": ".types",
    "MimeType": ".types",
    "MirrorAction": ".types",
    "MistralAiIntegrations": ".types",
    "MistralAiKeyAuth": ".types",
    "MistralAiModel": ".types",
    "MistralAiProviderAccount": ".types",
    "MlRepo": ".types",
    "MlRepoManifest": ".types",
    "Model": ".types",
    "ModelConfiguration": ".types",
    "ModelCostMetric": ".types",
    "ModelManifest": ".types",
    "ModelManifestFramework": ".types",
    "ModelManifestSource": ".types",
    "ModelProviderAccount": ".types",
    "ModelType": ".types",
    "ModelVersion": ".types",
    "ModelVersionEnvironment": ".types",
    "MultiPartUpload": ".types",
    "MultiPartUploadResponse": ".types",
    "MultiPartUploadStorageProvider": ".types",
    "NatsInputConfig": ".types",
    "NatsMetricConfig": ".types",
    "NatsOutputConfig": ".types",
    "NatsUserPasswordAuth": ".types",
    "NodeSelector": ".types",
    "NodeSelectorCapacityType": ".types",
    "Nodepool": ".types",
    "NodepoolSelector": ".types",
    "NomicIntegrations": ".types",
    "NomicKeyAuth": ".types",
    "NomicModel": ".types",
    "NomicProviderAccount": ".types",
    "NonNegativeFloat": ".types",
    "NotFoundError": ".errors",
    "NotImplementedError": ".errors",
    "Notebook": ".types",
    "NotebookConfig": ".types",
    "NotificationTarget": ".types",
    "NotificationTargetForAlertRule": ".types",
    "NvidiaGpu": ".types",
    "NvidiaMiggpu": ".types",
    "NvidiaMiggpuProfile": ".types",
    "NvidiaTimeslicingGpu": ".types",
    "OAuth2LoginProvider": ".types",
    "OciRepo": ".types",
    "OllamaIntegrations": ".types",
    "OllamaKeyAuth": ".types",
    "OllamaModel": ".types",
    "OllamaProviderAccount": ".types",
    "OnnxFramework": ".types",
    "OpenAiIntegrations": ".types",
    "OpenAiModel": ".types",
    "OpenAiModerationsGuardrailConfig": ".types",
    "OpenAiModerationsGuardrailConfigCategoryThresholdsValue": ".types",
    "OpenAiModerationsGuardrailConfigCategoryThresholdsValueHarassment": ".types",
    "OpenRouterApiKeyAuth": ".types",
    "OpenRouterIntegrations": ".types",
    "OpenRouterModel": ".types",
    "OpenRouterProviderAccount": ".types",
    "OpenaiApiKeyAuth": ".types",
    "OpenaiProviderAccount": ".types",
    "Operation": ".types",
    "OtelExporterGrpcConfig": ".types",
    "OtelExporterHttpConfig": ".types",
    "OtelExporterHttpConfigEncoding": ".types",
    "OwnedBy": ".types",
    "PaddleFramework": ".types",
    "PagerDuty": ".types",
    "PagerDutyIntegration": ".types",
    "PagerDutyIntegrationKeyAuth": ".types",
    "PagerDutyIntegrations": ".types",
    "PagerDutyProviderAccount": ".types",
    "Pagination": ".types",
    "PalmIntegrations": ".types",
    "PalmKeyAuth": ".types",
    "PalmModel": ".types",
    "PalmProviderAccount": ".types",
    "PaloAltoPrismaAirsGuardrailConfig": ".types",
    "PaloAltoPrismaAirsGuardrailConfigMode": ".types",
    "PaloAltoPrismaAirsKeyAuth": ".types",
    "PangeaGuardType": ".types",
    "PangeaGuardrailConfig": ".types",
    "PangeaGuardrailConfigOperation": ".types",
    "PangeaKeyAuth": ".types",
    "Param": ".types",
    "ParamParamType": ".types",
    "Parameters": ".types",
    "ParametersStop": ".types",
    "PatronusAnswerRelevanceCriteria": ".types",
    "PatronusAnswerRelevanceEvaluator": ".types",
    "PatronusEvaluator": ".types",
    "PatronusGliderCriteria": ".types",
    "PatronusGliderEvaluator": ".types",
    "PatronusGuardrailConfig": ".types",
    "PatronusGuardrailConfigTarget": ".types",
    "PatronusJudgeCriteria": ".types",
    "PatronusJudgeEvaluator": ".types",
    "PatronusKeyAuth": ".types",
    "PatronusPhiCriteria": ".types",
    "PatronusPhiEvaluator": ".types",
    "PatronusPiiCriteria": ".types",
    "PatronusPiiEvaluator": ".types",
    "PatronusToxicityCriteria": ".types",
    "PatronusToxicityEvaluator": ".types",
    "PerThousandEmbeddingTokensCostMetric": ".types",
    "PerThousandTokensCostMetric": ".types",
    "Permissions": ".types",
    "PerplexityAiKeyAuth": ".types",
    "PerplexityAiModel": ".types",
    "PerplexityAiProviderAccount": ".types",
    "PerplexityIntegrations": ".types",
    "PersonalAccessTokenManifest": ".types",
    "Pip": ".types",
    "Poetry": ".types",
    "PolicyActions": ".types",
    "PolicyEntityTypes": ".types",
    "PolicyFilters": ".types",
    "PolicyManifest": ".types",
    "PolicyManifestMode": ".types",
    "PolicyManifestOperation": ".types",
    "PolicyMutationOperation": ".types",
    "PolicyValidationOperation": ".types",
    "Port": ".types",
    "PortAppProtocol": ".types",
    "PortAuth": ".types",
    "PortProtocol": ".types",
    "PresignedUrlObject": ".types",
    "PriorityBasedLoadBalanceTarget": ".types",
    "PriorityBasedLoadBalancing": ".types",
    "PriorityBasedLoadBalancingRule": ".types",
    "PrometheusAlertRule": ".types",
    "Prompt": ".types",
    "PromptFooGuardType": ".types",
    "PromptFooGuardrailConfig": ".types",
    "PromptFooGuardrailConfigOperation": ".types",
    "PromptVersion": ".types",
    "ProviderAccounts": ".types",
    "PublicCostMetric": ".types",
    "PySparkTaskConfig": ".types",
    "PyTorchFramework": ".types",
    "PythonBuild": ".types",
    "PythonBuildCommand": ".types",
    "PythonBuildPythonDependencies": ".types",
    "PythonTaskConfig": ".types",
    "PythonTaskConfigImage": ".types",
    "PythonTaskConfigMountsItem": ".types",
    "QuayArtifactsRegistry": ".types",
    "QuayBasicAuth": ".types",
    "QuayIntegrations": ".types",
    "QuayProviderAccount": ".types",
    "QuerySpansRequestFiltersItem": ".traces",
    "QuerySpansResponse": ".types",
    "RStudio": ".types",
    "RateLimitConfig": ".types",
    "RateLimitRule": ".types",
    "RateLimitUnit": ".types",
    "RateLimitWhen": ".types",
    "Recommendation": ".types",
    "RefusalContentPart": ".types",
    "RegisterUsersResponse": ".types",
    "RemoteSource": ".types",
    "Resources": ".types",
    "ResourcesDevicesItem": ".types",
    "ResourcesNode": ".types",
    "RetryConfig": ".types",
    "RevokeAllPersonalAccessTokenResponse": ".types",
    "RoleManifest": ".types",
    "RolePermissions": ".types",
    "Rolling": ".types",
    "RpsMetric": ".types",
    "SagemakerModel": ".types",
    "SambaNovaIntegrations": ".types",
    "SambaNovaKeyAuth": ".types",
    "SambaNovaModel": ".types",
    "SambaNovaProviderAccount": ".types",
    "Schedule": ".types",
    "ScheduleConcurrencyPolicy": ".types",
    "Secret": ".types",
    "SecretGroup": ".types",
    "SecretGroupManifest": ".types",
    "SecretInput": ".types",
    "SecretMount": ".types",
    "SecretStoreConfig": ".types",
    "SecretVersion": ".types",
    "SelfHostedModel": ".types",
    "SelfHostedModelAuthData": ".types",
    "SelfHostedModelIntegrations": ".types",
    "SelfHostedModelModelServer": ".types",
    "SelfHostedModelProviderAccount": ".types",
    "Service": ".types",
    "ServiceAutoscaling": ".types",
    "ServiceAutoscalingMetrics": ".types",
    "ServiceReplicas": ".types",
    "ServiceRolloutStrategy": ".types",
    "Session": ".types",
    "SignedUrl": ".types",
    "SklearnFramework": ".types",
    "SklearnModelSchema": ".types",
    "SklearnSerializationFormat": ".types",
    "SlaCutoff": ".types",
    "SlackBot": ".types",
    "SlackBotAuth": ".types",
    "SlackBotIntegration": ".types",
    "SlackIntegrations": ".types",
    "SlackProviderAccount": ".types",
    "SlackWebhook": ".types",
    "SlackWebhookAuth": ".types",
    "SlackWebhookIntegration": ".types",
    "SmtpCredentials": ".types",
    "SnowflakeCortexIntegrations": ".types",
    "SnowflakeCortexModel": ".types",
    "SnowflakeCortexPatTokenAuth": ".types",
    "SnowflakeCortexProviderAccount": ".types",
    "SortDirection": ".types",
    "SpaCyFramework": ".types",
    "SpanAttributeFilter": ".types",
    "SpanAttributeFilterOperator": ".types",
    "SpanAttributeFilterValue": ".types",
    "SpanFieldFilter": ".types",
    "SpanFieldFilterOperator": ".types",
    "SpanFieldFilterSpanFieldName": ".types",
    "SpanFieldFilterValue": ".types",
    "SparkBuild": ".types",
    "SparkConfig": ".types",
    "SparkDriverConfig": ".types",
    "SparkExecutorConfig": ".types",
    "SparkExecutorConfigInstances": ".types",
    "SparkExecutorDynamicScaling": ".types",
    "SparkExecutorFixedInstances": ".types",
    "SparkImage": ".types",
    "SparkImageBuild": ".types",
    "SparkImageBuildBuildSource": ".types",
    "SparkJob": ".types",
    "SparkJobEntrypoint": ".types",
    "SparkJobImage": ".types",
    "SparkJobJavaEntrypoint": ".types",
    "SparkJobPythonEntrypoint": ".types",
    "SparkJobPythonNotebookEntrypoint": ".types",
    "SparkJobScalaEntrypoint": ".types",
    "SparkJobScalaNotebookEntrypoint": ".types",
    "SparkJobTriggerInput": ".types",
    "SqsInputConfig": ".types",
    "SqsOutputConfig": ".types",
    "SqsQueueMetricConfig": ".types",
    "SqsQueueMetricConfigAuth": ".types",
    "SshServer": ".types",
    "SshServerConfig": ".types",
    "SsoTeamManifest": ".types",
    "StageArtifactRequestManifest": ".artifact_versions",
    "StageArtifactResponse": ".types",
    "StaticVolumeConfig": ".types",
    "StatsModelsFramework": ".types",
    "StringDataMount": ".types",
    "Subject": ".types",
    "SubjectType": ".types",
    "SyncTokenInSecretStoreInfo": ".types",
    "SyncVirtualAccountTokenResponse": ".types",
    "SystemMessage": ".types",
    "SystemMessageContent": ".types",
    "TaskDockerFileBuild": ".types",
    "TaskPySparkBuild": ".types",
    "TaskPythonBuild": ".types",
    "Team": ".types",
    "TeamManifest": ".types",
    "TeamOwnedBy": ".types",
    "TeamsListRequestType": ".teams",
    "TensorFlowFramework": ".types",
    "TerminateJobResponse": ".types",
    "TextContentPart": ".types",
    "TextContentPartText": ".types",
    "TogetherAiIntegrations": ".types",
    "TogetherAiKeyAuth": ".types",
    "TogetherAiModel": ".types",
    "TogetherAiProviderAccount": ".types",
    "TokenPagination": ".types",
    "ToolCall": ".types",
    "ToolMessage": ".types",
    "ToolMessageContent": ".types",
    "ToolSchema": ".types",
    "TraceSpan": ".types",
    "TracingProject": ".types",
    "TracingProjectManifest": ".types",
    "TransformersFramework": ".types",
    "TriggerJobRequestInput": ".jobs",
    "TriggerJobRunResponse": ".types",
    "TrueFoundry": ".client",
    "TrueFoundryApplyRequestManifest": ".types",
    "TrueFoundryApplyResponse": ".types",
    "TrueFoundryApplyResponseAction": ".types",
    "TrueFoundryApplyResponseExistingManifest": ".types",
    "TrueFoundryArtifactSource": ".types",
    "TrueFoundryDbssm": ".types",
    "TrueFoundryDeleteRequestManifest": ".types",
    "TrueFoundryIntegrations": ".types",
    "TrueFoundryInteractiveLogin": ".types",
    "TrueFoundryManagedSource": ".types",
    "TrueFoundryProviderAccount": ".types",
    "TtlIntegrations": ".types",
    "TtlProviderAccount": ".types",
    "TtlRegistry": ".types",
    "UnauthorizedError": ".errors",
    "UnprocessableEntityError": ".errors",
    "UpdateSecretInput": ".types",
    "UpdateUserRolesResponse": ".types",
    "UpgradeData": ".types",
    "UsageCodeSnippet": ".types",
    "User": ".types",
    "UserMessage": ".types",
    "UserMessageContent": ".types",
    "UserMessageContentOneItem": ".types",
    "UserMetadata": ".types",
    "UserMetadataTenantRoleManagedBy": ".types",
    "UserResource": ".types",
    "UserRoleWithResource": ".types",
    "UserRoleWithResourceResourceType": ".types",
    "Uv": ".types",
    "ValidationError": ".types",
    "ValidationErrorLocItem": ".types",
    "VertexModel": ".types",
    "VirtualAccount": ".types",
    "VirtualAccountManifest": ".types",
    "VirtualAccountOwnedBy": ".types",
    "VirtualMcpServerIntegration": ".types",
    "VirtualMcpServerSource": ".types",
    "VirtualModel": ".types",
    "VirtualModelProviderAccount": ".types",
    "Volume": ".types",
    "VolumeBrowser": ".types",
    "VolumeConfig": ".types",
    "VolumeMount": ".types",
    "WebhookBasicAuth": ".types",
    "WebhookBearerAuth": ".types",
    "WebhookIntegration": ".types",
    "WebhookIntegrationAuthData": ".types",
    "WebhookIntegrations": ".types",
    "WebhookProviderAccount": ".types",
    "WeightBasedLoadBalancing": ".types",
    "WeightBasedLoadBalancingRule": ".types",
    "WorkbenchImage": ".types",
    "WorkerConfig": ".types",
    "WorkerConfigInputConfig": ".types",
    "WorkerConfigOutputConfig": ".types",
    "Workflow": ".types",
    "WorkflowAlert": ".types",
    "WorkflowFlyteEntitiesItem": ".types",
    "WorkflowSource": ".types",
    "Workspace": ".types",
    "WorkspaceManifest": ".types",
    "WorkspacesDeleteResponse": ".workspaces",
    "XgBoostFramework": ".types",
    "XgBoostModelSchema": ".types",
    "XgBoostSerializationFormat": ".types",
    "__version__": ".version",
    "alerts": ".alerts",
    "application_versions": ".application_versions",
    "applications": ".applications",
    "artifact_versions": ".artifact_versions",
    "artifacts": ".artifacts",
    "clusters": ".clusters",
    "data_directories": ".data_directories",
    "environments": ".environments",
    "events": ".events",
    "internal": ".internal",
    "jobs": ".jobs",
    "logs": ".logs",
    "ml_repos": ".ml_repos",
    "model_versions": ".model_versions",
    "models": ".models",
    "personal_access_tokens": ".personal_access_tokens",
    "prompt_versions": ".prompt_versions",
    "prompts": ".prompts",
    "secret_groups": ".secret_groups",
    "secrets": ".secrets",
    "teams": ".teams",
    "traces": ".traces",
    "users": ".users",
    "virtual_accounts": ".virtual_accounts",
    "workspaces": ".workspaces",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "Account",
    "ActivateUserResponse",
    "AddOnComponentSource",
    "AddonComponent",
    "AddonComponentName",
    "AddonComponentStatus",
    "Ai21Integrations",
    "Ai21KeyAuth",
    "Ai21Model",
    "Ai21ProviderAccount",
    "AiFeaturesSettings",
    "Alert",
    "AlertConfig",
    "AlertConfigResource",
    "AlertConfigResourceType",
    "AlertSeverity",
    "AlertStatus",
    "AmqpInputConfig",
    "AmqpMetricConfig",
    "AmqpOutputConfig",
    "AnthropicIntegrations",
    "AnthropicKeyAuth",
    "AnthropicModel",
    "AnthropicProviderAccount",
    "Application",
    "ApplicationDebugInfo",
    "ApplicationLifecycleStage",
    "ApplicationMetadata",
    "ApplicationProblem",
    "ApplicationSet",
    "ApplicationSetComponentsItem",
    "ApplicationType",
    "ApplicationsCancelDeploymentResponse",
    "ApplicationsListRequestDeviceTypeFilter",
    "ApplicationsListRequestLifecycleStage",
    "ApplyMlEntityResponse",
    "ApplyMlEntityResponseData",
    "ApplyTeamRequestManifest",
    "Artifact",
    "ArtifactManifest",
    "ArtifactManifestSource",
    "ArtifactPath",
    "ArtifactType",
    "ArtifactVersion",
    "ArtifactsCacheVolume",
    "ArtifactsDownload",
    "ArtifactsDownloadArtifactsItem",
    "AssistantMessage",
    "AssistantMessageContent",
    "AssistantMessageContentOneItem",
    "AsyncProcessorSidecar",
    "AsyncService",
    "AsyncServiceAutoscaling",
    "AsyncServiceAutoscalingMetrics",
    "AsyncServiceReplicas",
    "AsyncTrueFoundry",
    "AutoRotate",
    "Autoshutdown",
    "AwsAccessKeyAuth",
    "AwsAccessKeyBasedAuth",
    "AwsAssumedRoleBasedAuth",
    "AwsBedrockAssumedRoleBasedAuth",
    "AwsBedrockGuardrailConfig",
    "AwsBedrockGuardrailConfigAuthData",
    "AwsBedrockGuardrailConfigOperation",
    "AwsBedrockProviderAccount",
    "AwsBedrockProviderAccountAuthData",
    "AwsEcr",
    "AwsEcrAuthData",
    "AwsEksIntegration",
    "AwsEksIntegrationAuthData",
    "AwsInferentia",
    "AwsIntegrations",
    "AwsParameterStore",
    "AwsParameterStoreAuthData",
    "AwsProviderAccount",
    "AwsProviderAccountAuthData",
    "AwsRegion",
    "AwsS3",
    "AwsS3AuthData",
    "AwsSagemakerProviderAccount",
    "AwsSagemakerProviderAccountAuthData",
    "AwsSecretsManager",
    "AwsSecretsManagerAuthData",
    "AwsSqsAccessKeyBasedAuth",
    "AwsSqsAssumedRoleBasedAuth",
    "AzureAksIntegration",
    "AzureBasicAuth",
    "AzureBlobStorage",
    "AzureConnectionStringAuth",
    "AzureContainerRegistry",
    "AzureContentSafetyCategory",
    "AzureContentSafetyGuardrailConfig",
    "AzureFoundryModel",
    "AzureFoundryProviderAccount",
    "AzureIntegrations",
    "AzureKeyAuth",
    "AzureOAuth",
    "AzureOpenAiModel",
    "AzureOpenAiProviderAccount",
    "AzurePiiCategory",
    "AzurePiiGuardrailConfig",
    "AzurePiiGuardrailConfigDomain",
    "AzureProviderAccount",
    "AzureReposIntegration",
    "AzureVault",
    "BadRequestError",
    "BaseArtifactVersion",
    "BaseArtifactVersionManifest",
    "BaseAutoscaling",
    "BaseOAuth2Login",
    "BaseOAuth2LoginJwtSource",
    "BaseService",
    "BaseServiceImage",
    "BaseServiceMountsItem",
    "BaseWorkbenchInput",
    "BaseWorkbenchInputMountsItem",
    "BasicAuthCreds",
    "BedrockModel",
    "BitbucketIntegration",
    "BitbucketProviderAccount",
    "BlobStorageReference",
    "BlueGreen",
    "BudgetAlert",
    "BudgetConfig",
    "BudgetLimitUnit",
    "BudgetRule",
    "BudgetWhen",
    "Build",
    "BuildBuildSource",
    "BuildBuildSpec",
    "BuildInfo",
    "BuildStatus",
    "Canary",
    "CanaryStep",
    "CerebrasIntegrations",
    "CerebrasKeyAuth",
    "CerebrasModel",
    "CerebrasProviderAccount",
    "ChangePasswordResponse",
    "ChatPromptManifest",
    "ChatPromptManifestMcpServersItem",
    "ChatPromptManifestMessagesItem",
    "ChatPromptManifestResponseFormat",
    "ChatPromptManifestRoutingConfig",
    "ClouderaIntegrations",
    "ClouderaModel",
    "ClouderaProviderAccount",
    "ClouderaProviderAccountAuthData",
    "ClouderaTokenAuth",
    "ClouderaWorkloadAuthToken",
    "Cluster",
    "ClusterGateway",
    "ClusterManifest",
    "ClusterManifestClusterType",
    "ClusterManifestMonitoring",
    "ClusterManifestNodeLabelKeys",
    "ClusterManifestWorkbenchConfig",
    "ClusterType",
    "ClustersDeleteResponse",
    "Codeserver",
    "CohereIntegrations",
    "CohereKeyAuth",
    "CohereModel",
    "CohereProviderAccount",
    "Collaborator",
    "CommonToolsSettings",
    "Config",
    "ConflictError",
    "ContainerTaskConfig",
    "ContainerTaskConfigImage",
    "ContainerTaskConfigMountsItem",
    "CoreNatsOutputConfig",
    "CpuUtilizationMetric",
    "CreateMultiPartUploadRequest",
    "CreatePersonalAccessTokenResponse",
    "CronMetric",
    "CustomBasicAuth",
    "CustomBearerAuth",
    "CustomBlobStorage",
    "CustomGuardrailConfig",
    "CustomGuardrailConfigAuthData",
    "CustomGuardrailConfigOperation",
    "CustomGuardrailConfigTarget",
    "CustomHelmRepo",
    "CustomIntegrations",
    "CustomJwtAuthIntegration",
    "CustomProviderAccount",
    "CustomTlsSettings",
    "CustomUsernamePasswordArtifactsRegistry",
    "DataDirectory",
    "DataDirectoryManifest",
    "DataDirectoryManifestSource",
    "DatabricksApiKeyAuth",
    "DatabricksIntegrations",
    "DatabricksModel",
    "DatabricksProviderAccount",
    "DatabricksProviderAccountAuthData",
    "DatabricksServicePrincipalAuth",
    "DeactivateUserResponse",
    "DeepinfraIntegrations",
    "DeepinfraKeyAuth",
    "DeepinfraModel",
    "DeepinfraProviderAccount",
    "DeleteApplicationResponse",
    "DeleteJobRunResponse",
    "DeletePersonalAccessTokenResponse",
    "DeleteSecretGroupResponse",
    "DeleteTeamResponse",
    "DeleteUserResponse",
    "DeleteVirtualAccountResponse",
    "Deployment",
    "DeploymentBuild",
    "DeploymentManifest",
    "DeploymentStatus",
    "DeploymentStatusValue",
    "DeploymentTransition",
    "DeveloperMessage",
    "DeveloperMessageContent",
    "DockerFileBuild",
    "DockerFileBuildCommand",
    "DockerhubBasicAuth",
    "DockerhubIntegrations",
    "DockerhubProviderAccount",
    "DockerhubRegistry",
    "DynamicVolumeConfig",
    "Email",
    "EmailNotificationChannel",
    "EmptyResponse",
    "Endpoint",
    "EnkryptAiGuardrailConfig",
    "EnkryptAiGuardrailConfigOperation",
    "EnkryptAiKeyAuth",
    "Environment",
    "EnvironmentColor",
    "EnvironmentManifest",
    "EnvironmentOptimizeFor",
    "Event",
    "EventChart",
    "EventChartCategory",
    "EventInvolvedObject",
    "ExpectationFailedError",
    "ExternalBlobStorageSource",
    "FailedDependencyError",
    "FastAiFramework",
    "FiddlerGuardType",
    "FiddlerGuardrailConfig",
    "FiddlerKeyAuth",
    "FileInfo",
    "FlyteLaunchPlan",
    "FlyteLaunchPlanId",
    "FlyteLaunchPlanSpec",
    "FlyteTask",
    "FlyteTaskCustom",
    "FlyteTaskCustomTruefoundry",
    "FlyteTaskId",
    "FlyteTaskTemplate",
    "FlyteWorkflow",
    "FlyteWorkflowId",
    "FlyteWorkflowTemplate",
    "ForbiddenError",
    "ForwardAction",
    "Function",
    "FunctionSchema",
    "GatewayConfig",
    "GatewayConfiguration",
    "GatewayOtelConfig",
    "GatewayOtelConfigOtelTracesExporterConfig",
    "GatewayRequestMetadataFilter",
    "GatewayRequestMetadataFilterOperator",
    "GatewayRequestMetadataFilterValue",
    "GcpApiKeyAuth",
    "GcpGcr",
    "GcpGcs",
    "GcpGkeIntegration",
    "GcpGsm",
    "GcpIntegrations",
    "GcpKeyFileAuth",
    "GcpProviderAccount",
    "GcpRegion",
    "GcpTpu",
    "GeminiModel",
    "GetAlertsResponse",
    "GetApplicationDeploymentResponse",
    "GetApplicationResponse",
    "GetArtifactResponse",
    "GetArtifactVersionResponse",
    "GetAuthenticatedVcsurlResponse",
    "GetAutoProvisioningStateResponse",
    "GetChartsResponse",
    "GetClusterResponse",
    "GetDataDirectoryResponse",
    "GetEnvironmentResponse",
    "GetEventsResponse",
    "GetJobRunResponse",
    "GetLogsResponse",
    "GetMlRepoResponse",
    "GetModelResponse",
    "GetModelVersionResponse",
    "GetOrCreatePersonalAccessTokenResponse",
    "GetPromptResponse",
    "GetPromptVersionResponse",
    "GetSecretGroupResponse",
    "GetSecretResponse",
    "GetSignedUrLsRequest",
    "GetSignedUrLsResponse",
    "GetSuggestedDeploymentEndpointResponse",
    "GetTeamResponse",
    "GetTokenForVirtualAccountResponse",
    "GetUserResourcesResponse",
    "GetUserResponse",
    "GetUserTeamsResponse",
    "GetVirtualAccountResponse",
    "GetWorkspaceResponse",
    "GitHelmRepo",
    "GitRepositoryExistsResponse",
    "GitSource",
    "GithubIntegration",
    "GithubProviderAccount",
    "GitlabIntegration",
    "GitlabProviderAccount",
    "GluonFramework",
    "GoogleGeminiProviderAccount",
    "GoogleVertexProviderAccount",
    "Graph",
    "GraphChartType",
    "GroqIntegrations",
    "GroqKeyAuth",
    "GroqModel",
    "GroqProviderAccount",
    "GuardrailConfigGroup",
    "GuardrailConfigIntegrations",
    "Guardrails",
    "GuardrailsConfig",
    "GuardrailsRule",
    "GuardrailsWhen",
    "H2OFramework",
    "HashicorpIntegrations",
    "HashicorpProviderAccount",
    "HashicorpTokenAuth",
    "HashicorpVaultIntegration",
    "HeaderMatch",
    "HeaderRoutingConfig",
    "HealthProbe",
    "Helm",
    "HelmRepo",
    "HelmSource",
    "HttpError",
    "HttpErrorCode",
    "HttpProbe",
    "HttpValidationError",
    "HuggingfaceArtifactSource",
    "IChange",
    "IChangeOperation",
    "Image",
    "ImageCommand",
    "ImageContentPart",
    "ImageContentPartImageUrl",
    "ImageContentPartImageUrlUrl",
    "InferMethodName",
    "InfraProviderAccount",
    "IngressControllerConfig",
    "InputOutputBasedCostMetricValue",
    "Intercept",
    "InterceptRulesItem",
    "InterceptRulesItemAction",
    "InternalArtifactVersion",
    "InternalListArtifactVersionsResponse",
    "InternalListArtifactVersionsResponseDataItem",
    "InternalModelVersion",
    "InviteUserResponse",
    "IsClusterConnectedResponse",
    "JFrogIntegrations",
    "JfrogArtifactsRegistry",
    "JfrogBasicAuth",
    "JfrogProviderAccount",
    "Job",
    "JobAlert",
    "JobImage",
    "JobMountsItem",
    "JobRun",
    "JobRunStatus",
    "JobRunsSortBy",
    "JobTrigger",
    "JobTriggerInput",
    "JobTriggerInputCommand",
    "JsonObjectResponseFormat",
    "JsonSchema",
    "JsonSchemaResponseFormat",
    "Jwt",
    "JwtAuthConfig",
    "JwtAuthConfigClaimsItem",
    "KafkaInputConfig",
    "KafkaMetricConfig",
    "KafkaOutputConfig",
    "KafkaSaslAuth",
    "KerasFramework",
    "Kustomize",
    "LatencyBasedLoadBalanceTarget",
    "LatencyBasedLoadBalancing",
    "LatencyBasedLoadBalancingRule",
    "LibraryName",
    "LightGbmFramework",
    "ListApplicationDeploymentsResponse",
    "ListApplicationsResponse",
    "ListArtifactVersionsResponse",
    "ListArtifactsResponse",
    "ListClusterAddonsResponse",
    "ListClustersResponse",
    "ListDataDirectoriesResponse",
    "ListEnvironmentsResponse",
    "ListFilesRequest",
    "ListFilesResponse",
    "ListJobRunResponse",
    "ListMlReposResponse",
    "ListModelVersionsResponse",
    "ListModelsResponse",
    "ListPersonalAccessTokenResponse",
    "ListPromptVersionsResponse",
    "ListPromptsResponse",
    "ListSecretGroupResponse",
    "ListSecretsResponse",
    "ListTeamsResponse",
    "ListUsersResponse",
    "ListVirtualAccountResponse",
    "ListWorkspacesResponse",
    "LoadBalanceTarget",
    "LoadBalancingConfig",
    "LoadBalancingRule",
    "LoadBalancingWhen",
    "LocalArtifactSource",
    "LocalModelSource",
    "LocalSource",
    "Log",
    "LogsFilterQuery",
    "LogsFilterQueryType",
    "LogsResponse",
    "LogsSearchFilterType",
    "LogsSearchOperatorType",
    "LogsSortingDirection",
    "Manual",
    "McpServerAuth",
    "McpServerHeaderAuth",
    "McpServerHeaderOverrideAuth",
    "McpServerIntegration",
    "McpServerIntegrationTransport",
    "McpServerIntegrations",
    "McpServerOAuth2",
    "McpServerOAuth2JwtSource",
    "McpServerPassthrough",
    "McpServerProviderAccount",
    "McpServerToolDetails",
    "McpServerWithFqn",
    "McpServerWithUrl",
    "McpTool",
    "Metadata",
    "MethodNotAllowedError",
    "Metric",
    "MimeType",
    "MirrorAction",
    "MistralAiIntegrations",
    "MistralAiKeyAuth",
    "MistralAiModel",
    "MistralAiProviderAccount",
    "MlRepo",
    "MlRepoManifest",
    "Model",
    "ModelConfiguration",
    "ModelCostMetric",
    "ModelManifest",
    "ModelManifestFramework",
    "ModelManifestSource",
    "ModelProviderAccount",
    "ModelType",
    "ModelVersion",
    "ModelVersionEnvironment",
    "MultiPartUpload",
    "MultiPartUploadResponse",
    "MultiPartUploadStorageProvider",
    "NatsInputConfig",
    "NatsMetricConfig",
    "NatsOutputConfig",
    "NatsUserPasswordAuth",
    "NodeSelector",
    "NodeSelectorCapacityType",
    "Nodepool",
    "NodepoolSelector",
    "NomicIntegrations",
    "NomicKeyAuth",
    "NomicModel",
    "NomicProviderAccount",
    "NonNegativeFloat",
    "NotFoundError",
    "NotImplementedError",
    "Notebook",
    "NotebookConfig",
    "NotificationTarget",
    "NotificationTargetForAlertRule",
    "NvidiaGpu",
    "NvidiaMiggpu",
    "NvidiaMiggpuProfile",
    "NvidiaTimeslicingGpu",
    "OAuth2LoginProvider",
    "OciRepo",
    "OllamaIntegrations",
    "OllamaKeyAuth",
    "OllamaModel",
    "OllamaProviderAccount",
    "OnnxFramework",
    "OpenAiIntegrations",
    "OpenAiModel",
    "OpenAiModerationsGuardrailConfig",
    "OpenAiModerationsGuardrailConfigCategoryThresholdsValue",
    "OpenAiModerationsGuardrailConfigCategoryThresholdsValueHarassment",
    "OpenRouterApiKeyAuth",
    "OpenRouterIntegrations",
    "OpenRouterModel",
    "OpenRouterProviderAccount",
    "OpenaiApiKeyAuth",
    "OpenaiProviderAccount",
    "Operation",
    "OtelExporterGrpcConfig",
    "OtelExporterHttpConfig",
    "OtelExporterHttpConfigEncoding",
    "OwnedBy",
    "PaddleFramework",
    "PagerDuty",
    "PagerDutyIntegration",
    "PagerDutyIntegrationKeyAuth",
    "PagerDutyIntegrations",
    "PagerDutyProviderAccount",
    "Pagination",
    "PalmIntegrations",
    "PalmKeyAuth",
    "PalmModel",
    "PalmProviderAccount",
    "PaloAltoPrismaAirsGuardrailConfig",
    "PaloAltoPrismaAirsGuardrailConfigMode",
    "PaloAltoPrismaAirsKeyAuth",
    "PangeaGuardType",
    "PangeaGuardrailConfig",
    "PangeaGuardrailConfigOperation",
    "PangeaKeyAuth",
    "Param",
    "ParamParamType",
    "Parameters",
    "ParametersStop",
    "PatronusAnswerRelevanceCriteria",
    "PatronusAnswerRelevanceEvaluator",
    "PatronusEvaluator",
    "PatronusGliderCriteria",
    "PatronusGliderEvaluator",
    "PatronusGuardrailConfig",
    "PatronusGuardrailConfigTarget",
    "PatronusJudgeCriteria",
    "PatronusJudgeEvaluator",
    "PatronusKeyAuth",
    "PatronusPhiCriteria",
    "PatronusPhiEvaluator",
    "PatronusPiiCriteria",
    "PatronusPiiEvaluator",
    "PatronusToxicityCriteria",
    "PatronusToxicityEvaluator",
    "PerThousandEmbeddingTokensCostMetric",
    "PerThousandTokensCostMetric",
    "Permissions",
    "PerplexityAiKeyAuth",
    "PerplexityAiModel",
    "PerplexityAiProviderAccount",
    "PerplexityIntegrations",
    "PersonalAccessTokenManifest",
    "Pip",
    "Poetry",
    "PolicyActions",
    "PolicyEntityTypes",
    "PolicyFilters",
    "PolicyManifest",
    "PolicyManifestMode",
    "PolicyManifestOperation",
    "PolicyMutationOperation",
    "PolicyValidationOperation",
    "Port",
    "PortAppProtocol",
    "PortAuth",
    "PortProtocol",
    "PresignedUrlObject",
    "PriorityBasedLoadBalanceTarget",
    "PriorityBasedLoadBalancing",
    "PriorityBasedLoadBalancingRule",
    "PrometheusAlertRule",
    "Prompt",
    "PromptFooGuardType",
    "PromptFooGuardrailConfig",
    "PromptFooGuardrailConfigOperation",
    "PromptVersion",
    "ProviderAccounts",
    "PublicCostMetric",
    "PySparkTaskConfig",
    "PyTorchFramework",
    "PythonBuild",
    "PythonBuildCommand",
    "PythonBuildPythonDependencies",
    "PythonTaskConfig",
    "PythonTaskConfigImage",
    "PythonTaskConfigMountsItem",
    "QuayArtifactsRegistry",
    "QuayBasicAuth",
    "QuayIntegrations",
    "QuayProviderAccount",
    "QuerySpansRequestFiltersItem",
    "QuerySpansResponse",
    "RStudio",
    "RateLimitConfig",
    "RateLimitRule",
    "RateLimitUnit",
    "RateLimitWhen",
    "Recommendation",
    "RefusalContentPart",
    "RegisterUsersResponse",
    "RemoteSource",
    "Resources",
    "ResourcesDevicesItem",
    "ResourcesNode",
    "RetryConfig",
    "RevokeAllPersonalAccessTokenResponse",
    "RoleManifest",
    "RolePermissions",
    "Rolling",
    "RpsMetric",
    "SagemakerModel",
    "SambaNovaIntegrations",
    "SambaNovaKeyAuth",
    "SambaNovaModel",
    "SambaNovaProviderAccount",
    "Schedule",
    "ScheduleConcurrencyPolicy",
    "Secret",
    "SecretGroup",
    "SecretGroupManifest",
    "SecretInput",
    "SecretMount",
    "SecretStoreConfig",
    "SecretVersion",
    "SelfHostedModel",
    "SelfHostedModelAuthData",
    "SelfHostedModelIntegrations",
    "SelfHostedModelModelServer",
    "SelfHostedModelProviderAccount",
    "Service",
    "ServiceAutoscaling",
    "ServiceAutoscalingMetrics",
    "ServiceReplicas",
    "ServiceRolloutStrategy",
    "Session",
    "SignedUrl",
    "SklearnFramework",
    "SklearnModelSchema",
    "SklearnSerializationFormat",
    "SlaCutoff",
    "SlackBot",
    "SlackBotAuth",
    "SlackBotIntegration",
    "SlackIntegrations",
    "SlackProviderAccount",
    "SlackWebhook",
    "SlackWebhookAuth",
    "SlackWebhookIntegration",
    "SmtpCredentials",
    "SnowflakeCortexIntegrations",
    "SnowflakeCortexModel",
    "SnowflakeCortexPatTokenAuth",
    "SnowflakeCortexProviderAccount",
    "SortDirection",
    "SpaCyFramework",
    "SpanAttributeFilter",
    "SpanAttributeFilterOperator",
    "SpanAttributeFilterValue",
    "SpanFieldFilter",
    "SpanFieldFilterOperator",
    "SpanFieldFilterSpanFieldName",
    "SpanFieldFilterValue",
    "SparkBuild",
    "SparkConfig",
    "SparkDriverConfig",
    "SparkExecutorConfig",
    "SparkExecutorConfigInstances",
    "SparkExecutorDynamicScaling",
    "SparkExecutorFixedInstances",
    "SparkImage",
    "SparkImageBuild",
    "SparkImageBuildBuildSource",
    "SparkJob",
    "SparkJobEntrypoint",
    "SparkJobImage",
    "SparkJobJavaEntrypoint",
    "SparkJobPythonEntrypoint",
    "SparkJobPythonNotebookEntrypoint",
    "SparkJobScalaEntrypoint",
    "SparkJobScalaNotebookEntrypoint",
    "SparkJobTriggerInput",
    "SqsInputConfig",
    "SqsOutputConfig",
    "SqsQueueMetricConfig",
    "SqsQueueMetricConfigAuth",
    "SshServer",
    "SshServerConfig",
    "SsoTeamManifest",
    "StageArtifactRequestManifest",
    "StageArtifactResponse",
    "StaticVolumeConfig",
    "StatsModelsFramework",
    "StringDataMount",
    "Subject",
    "SubjectType",
    "SyncTokenInSecretStoreInfo",
    "SyncVirtualAccountTokenResponse",
    "SystemMessage",
    "SystemMessageContent",
    "TaskDockerFileBuild",
    "TaskPySparkBuild",
    "TaskPythonBuild",
    "Team",
    "TeamManifest",
    "TeamOwnedBy",
    "TeamsListRequestType",
    "TensorFlowFramework",
    "TerminateJobResponse",
    "TextContentPart",
    "TextContentPartText",
    "TogetherAiIntegrations",
    "TogetherAiKeyAuth",
    "TogetherAiModel",
    "TogetherAiProviderAccount",
    "TokenPagination",
    "ToolCall",
    "ToolMessage",
    "ToolMessageContent",
    "ToolSchema",
    "TraceSpan",
    "TracingProject",
    "TracingProjectManifest",
    "TransformersFramework",
    "TriggerJobRequestInput",
    "TriggerJobRunResponse",
    "TrueFoundry",
    "TrueFoundryApplyRequestManifest",
    "TrueFoundryApplyResponse",
    "TrueFoundryApplyResponseAction",
    "TrueFoundryApplyResponseExistingManifest",
    "TrueFoundryArtifactSource",
    "TrueFoundryDbssm",
    "TrueFoundryDeleteRequestManifest",
    "TrueFoundryIntegrations",
    "TrueFoundryInteractiveLogin",
    "TrueFoundryManagedSource",
    "TrueFoundryProviderAccount",
    "TtlIntegrations",
    "TtlProviderAccount",
    "TtlRegistry",
    "UnauthorizedError",
    "UnprocessableEntityError",
    "UpdateSecretInput",
    "UpdateUserRolesResponse",
    "UpgradeData",
    "UsageCodeSnippet",
    "User",
    "UserMessage",
    "UserMessageContent",
    "UserMessageContentOneItem",
    "UserMetadata",
    "UserMetadataTenantRoleManagedBy",
    "UserResource",
    "UserRoleWithResource",
    "UserRoleWithResourceResourceType",
    "Uv",
    "ValidationError",
    "ValidationErrorLocItem",
    "VertexModel",
    "VirtualAccount",
    "VirtualAccountManifest",
    "VirtualAccountOwnedBy",
    "VirtualMcpServerIntegration",
    "VirtualMcpServerSource",
    "VirtualModel",
    "VirtualModelProviderAccount",
    "Volume",
    "VolumeBrowser",
    "VolumeConfig",
    "VolumeMount",
    "WebhookBasicAuth",
    "WebhookBearerAuth",
    "WebhookIntegration",
    "WebhookIntegrationAuthData",
    "WebhookIntegrations",
    "WebhookProviderAccount",
    "WeightBasedLoadBalancing",
    "WeightBasedLoadBalancingRule",
    "WorkbenchImage",
    "WorkerConfig",
    "WorkerConfigInputConfig",
    "WorkerConfigOutputConfig",
    "Workflow",
    "WorkflowAlert",
    "WorkflowFlyteEntitiesItem",
    "WorkflowSource",
    "Workspace",
    "WorkspaceManifest",
    "WorkspacesDeleteResponse",
    "XgBoostFramework",
    "XgBoostModelSchema",
    "XgBoostSerializationFormat",
    "__version__",
    "alerts",
    "application_versions",
    "applications",
    "artifact_versions",
    "artifacts",
    "clusters",
    "data_directories",
    "environments",
    "events",
    "internal",
    "jobs",
    "logs",
    "ml_repos",
    "model_versions",
    "models",
    "personal_access_tokens",
    "prompt_versions",
    "prompts",
    "secret_groups",
    "secrets",
    "teams",
    "traces",
    "users",
    "virtual_accounts",
    "workspaces",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.gateway_request_metadata_filter import GatewayRequestMetadataFilter
from ...types.span_attribute_filter import SpanAttributeFilter
from ...types.span_field_filter import SpanFieldFilter

QuerySpansRequestFiltersItem = typing.Union[SpanFieldFilter, SpanAttributeFilter, GatewayRequestMetadataFilter]



# This file was auto-generated by Fern from our API Definition.

import typing

from .spark_executor_dynamic_scaling import SparkExecutorDynamicScaling
from .spark_executor_fixed_instances import SparkExecutorFixedInstances

SparkExecutorConfigInstances = typing.Union[SparkExecutorFixedInstances, SparkExecutorDynamicScaling]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .artifact_manifest import ArtifactManifest
from .subject import Subject


class ArtifactVersion(UniversalBaseModel):
    id: str
    fqn: str
    created_by_subject: Subject
    created_at: typing.Optional[dt.datetime] = None
    updated_at: typing.Optional[dt.datetime] = None
    manifest: ArtifactManifest
    usage_code_snippet: typing.Optional[str] = None
    ml_repo_id: str
    tags: typing.Optional[typing.List[str]] = None
    artifact_id: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.pagination import AsyncPager, SyncPager
from ..core.request_options import RequestOptions
from ..types.artifact_version import ArtifactVersion
from ..types.empty_response import EmptyResponse
from ..types.file_info import FileInfo
from ..types.get_artifact_version_response import GetArtifactVersionResponse
from ..types.get_signed_ur_ls_response import GetSignedUrLsResponse
from ..types.list_artifact_versions_response import ListArtifactVersionsResponse
from ..types.list_files_response import ListFilesResponse
from ..types.multi_part_upload_response import MultiPartUploadResponse
from ..types.operation import Operation
from ..types.stage_artifact_response import StageArtifactResponse
from .raw_client import AsyncRawArtifactVersionsClient, RawArtifactVersionsClient
from .types.stage_artifact_request_manifest import StageArtifactRequestManifest

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ArtifactVersionsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawArtifactVersionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawArtifactVersionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawArtifactVersionsClient
        """
        return self._raw_client

    def apply_tags(
        self,
        *,
        artifact_version_id: str,
        tags: typing.Sequence[str],
        force: typing.Optional[bool] = False,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EmptyResponse:
        """
        Parameters
        ----------
        artifact_version_id : str

        tags : typing.Sequence[str]

        force : typing.Optional[bool]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EmptyResponse
            Successful Response

        Examples
        --------
        from truefoundry_sdk import TrueFoundry

        client = TrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )
        client.artifact_versions.apply_tags(
            artifact_version_id="artifact_version_id",
            tags=["tags"],
        )
        """
        _response = self._raw_client.apply_tags(
            artifact_version_id=artifact_version_id, tags=tags, force=force, request_options=request_options
        )
        return _response.data

    def get(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> GetArtifactVersionResponse:
        """
        Get artifact version API

        Parameters
        ----------
        id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetArtifactVersionResponse
            Successful Response

        Examples
        --------
        from truefoundry_sdk import TrueFoundry

        client = TrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )
        client.artifact_versions.get(
            id="id",
        )
        """
        _response = self._raw_client.get(id, request_options=request_options)
        return _response.data

    def delete(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> EmptyResponse:
        """
        Delete artifact versions API

        Parameters
        ----------
        id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EmptyResponse
            Successful Response

        Examples
        --------
        from truefoundry_sdk import TrueFoundry

        client = TrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )
        client.artifact_versions.delete(
            id="id",
        )
        """
        _response = self._raw_client.delete(id, request_options=request_options)
        return _response.data

    def list(
        self,
        *,
        tag: typing.Optional[str] = None,
        fqn: typing.Optional[str] = None,
        artifact_id: typing.Optional[str] = None,
        ml_repo_id: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        version: typing.Optional[int] = None,
        run_ids: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        run_steps: typing.Optional[typing.Union[int, typing.Sequence[int]]] = None,
        offset: typing.Optional[int] = 0,
        limit: typing.Optional[int] = 100,
        include_internal_metadata: typing.Optional[bool] = False,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SyncPager[ArtifactVersion, ListArtifactVersionsResponse]:
        """
        List artifact version API

        Parameters
        ----------
        tag : typing.Optional[str]

        fqn : typing.Optional[str]

        artifact_id : typing.Optional[str]

        ml_repo_id : typing.Optional[str]

        name : typing.Optional[str]

        version : typing.Optional[int]

        run_ids : typing.Optional[typing.Union[str, typing.Sequence[str]]]

        run_steps : typing.Optional[typing.Union[int, typing.Sequence[int]]]

        offset : typing.Optional[int]

        limit : typing.Optional[int]

        include_internal_metadata : typing.Optional[bool]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SyncPager[ArtifactVersion, ListArtifactVersionsResponse]
            Successful Response

        Examples
        --------
        from truefoundry_sdk import TrueFoundry

        client = TrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )
        response = client.artifact_versions.list(
            tag="tag",
            fqn="fqn",
            artifact_id="artifact_id",
            ml_repo_id="ml_repo_id",
            name="name",
            version=1,
            offset=1,
            limit=1,
            include_internal_metadata=True,
        )
        for item in response:
            yield item
        # alternatively, you can paginate page-by-page
        for page in response.iter_pages():
            yield page
        """
        return self._raw_client.list(
            tag=tag,
            fqn=fqn,
            artifact_id=artifact_id,
            ml_repo_id=ml_repo_id,
            name=name,
            version=version,
            run_ids=run_ids,
            run_steps=run_steps,
            offset=offset,
            limit=limit,
            include_internal_metadata=include_internal_metadata,
            request_options=request_options,
        )

    def get_signed_urls(
        self,
        *,
        id: str,
        paths: typing.Sequence[str],
        operation: Operation,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetSignedUrLsResponse:
        """
        Parameters
        ----------
        id : str

        paths : typing.Sequence[str]

        operation : Operation

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetSignedUrLsResponse
            Successful Response

        Examples
        --------
        from truefoundry_sdk import Operation, TrueFoundry

        client = TrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )
        client.artifact_versions.get_signed_urls(
            id="id",
            paths=["paths"],
            operation=Operation.READ,
        )
        """
        _response = self._raw_client.get_signed_urls(
            id=id, paths=paths, operation=operation, request_options=request_options
        )
        return _response.data

    def create_multi_part_upload(
        self, *, id: str, path: str, num_parts: int, request_options: typing.Optional[RequestOptions] = None
    ) -> MultiPartUploadResponse:
        """
        Parameters
        ----------
        id : str

        path : str

        num_parts : int

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        MultiPartUploadResponse
            Successful Response

        Examples
        --------
        from truefoundry_sdk import TrueFoundry

        client = TrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )
        client.artifact_versions.create_multi_part_upload(
            id="id",
            path="path",
            num_parts=1,
        )
        """
        _response = self._raw_client.create_multi_part_upload(
            id=id, path=path, num_parts=num_parts, request_options=request_options
        )
        return _response.data

    def stage(
        self, *, manifest: StageArtifactRequestManifest, request_options: typing.Optional[RequestOptions] = None
    ) -> StageArtifactResponse:
        """
        Parameters
        ----------
        manifest : StageArtifactRequestManifest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        StageArtifactResponse
            Successful Response

        Examples
        --------
        from truefoundry_sdk import ModelManifest, TrueFoundry, TrueFoundryManagedSource

        client = TrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )
        client.artifact_versions.stage(
            manifest=ModelManifest(
                name="name",
                metadata={"key": "value"},
                ml_repo="ml_repo",
                source=TrueFoundryManagedSource(),
            ),
        )
        """
        _response = self._raw_client.stage(manifest=manifest, request_options=request_options)
        return _response.data

    def list_files(
        self,
        *,
        id: str,
        path: typing.Optional[str] = OMIT,
        limit: typing.Optional[int] = OMIT,
        page_token: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SyncPager[FileInfo, ListFilesResponse]:
        """
        Parameters
        ----------
        id : str

        path : typing.Optional[str]

        limit : typing.Optional[int]

        page_token : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SyncPager[FileInfo, ListFilesResponse]
            Successful Response

        Examples
        --------
        from truefoundry_sdk import TrueFoundry

        client = TrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )
        response = client.artifact_versions.list_files(
            id="id",
        )
        for item in response:
            yield item
        # alternatively, you can paginate page-by-page
        for page in response.iter_pages():
            yield page
        """
        return self._raw_client.list_files(
            id=id, path=path, limit=limit, page_token=page_token, request_options=request_options
        )

    def mark_stage_failure(self, *, id: str, request_options: typing.Optional[RequestOptions] = None) -> EmptyResponse:
        """
        Parameters
        ----------
        id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EmptyResponse
            Successful Response

        Examples
        --------
        from truefoundry_sdk import TrueFoundry

        client = TrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )
        client.artifact_versions.mark_stage_failure(
            id="id",
        )
        """
        _response = self._raw_client.mark_stage_failure(id=id, request_options=request_options)
        return _response.data


class AsyncArtifactVersionsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawArtifactVersionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawArtifactVersionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawArtifactVersionsClient
        """
        return self._raw_client

    async def apply_tags(
        self,
        *,
        artifact_version_id: str,
        tags: typing.Sequence[str],
        force: typing.Optional[bool] = False,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EmptyResponse:
        """
        Parameters
        ----------
        artifact_version_id : str

        tags : typing.Sequence[str]

        force : typing.Optional[bool]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EmptyResponse
            Successful Response

        Examples
        --------
        import asyncio

        from truefoundry_sdk import AsyncTrueFoundry

        client = AsyncTrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.artifact_versions.apply_tags(
                artifact_version_id="artifact_version_id",
                tags=["tags"],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.apply_tags(
            artifact_version_id=artifact_version_id, tags=tags, force=force, request_options=request_options
        )
        return _response.data

    async def get(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetArtifactVersionResponse:
        """
        Get artifact version API

        Parameters
        ----------
        id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetArtifactVersionResponse
            Successful Response

        Examples
        --------
        import asyncio

        from truefoundry_sdk import AsyncTrueFoundry

        client = AsyncTrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.artifact_versions.get(
                id="id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(id, request_options=request_options)
        return _response.data

    async def delete(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> EmptyResponse:
        """
        Delete artifact versions API

        Parameters
        ----------
        id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EmptyResponse
            Successful Response

        Examples
        --------
        import asyncio

        from truefoundry_sdk import AsyncTrueFoundry

        client = AsyncTrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.artifact_versions.delete(
                id="id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(id, request_options=request_options)
        return _response.data

    async def list(
        self,
        *,
        tag: typing.Optional[str] = None,
        fqn: typing.Optional[str] = None,
        artifact_id: typing.Optional[str] = None,
        ml_repo_id: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        version: typing.Optional[int] = None,
        run_ids: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        run_steps: typing.Optional[typing.Union[int, typing.Sequence[int]]] = None,
        offset: typing.Optional[int] = 0,
        limit: typing.Optional[int] = 100,
        include_internal_metadata: typing.Optional[bool] = False,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncPager[ArtifactVersion, ListArtifactVersionsResponse]:
        """
        List artifact version API

        Parameters
        ----------
        tag : typing.Optional[str]

        fqn : typing.Optional[str]

        artifact_id : typing.Optional[str]

        ml_repo_id : typing.Optional[str]

        name : typing.Optional[str]

        version : typing.Optional[int]

        run_ids : typing.Optional[typing.Union[str, typing.Sequence[str]]]

        run_steps : typing.Optional[typing.Union[int, typing.Sequence[int]]]

        offset : typing.Optional[int]

        limit : typing.Optional[int]

        include_internal_metadata : typing.Optional[bool]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncPager[ArtifactVersion, ListArtifactVersionsResponse]
            Successful Response

        Examples
        --------
        import asyncio

        from truefoundry_sdk import AsyncTrueFoundry

        client = AsyncTrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            response = await client.artifact_versions.list(
                tag="tag",
                fqn="fqn",
                artifact_id="artifact_id",
                ml_repo_id="ml_repo_id",
                name="name",
                version=1,
                offset=1,
                limit=1,
                include_internal_metadata=True,
            )
            async for item in response:
                yield item

            # alternatively, you can paginate page-by-page
            async for page in response.iter_pages():
                yield page


        asyncio.run(main())
        """
        return await self._raw_client.list(
            tag=tag,
            fqn=fqn,
            artifact_id=artifact_id,
            ml_repo_id=ml_repo_id,
            name=name,
            version=version,
            run_ids=run_ids,
            run_steps=run_steps,
            offset=offset,
            limit=limit,
            include_internal_metadata=include_internal_metadata,
            request_options=request_options,
        )

    async def get_signed_urls(
        self,
        *,
        id: str,
        paths: typing.Sequence[str],
        operation: Operation,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetSignedUrLsResponse:
        """
        Parameters
        ----------
        id : str

        paths : typing.Sequence[str]

        operation : Operation

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetSignedUrLsResponse
            Successful Response

        Examples
        --------
        import asyncio

        from truefoundry_sdk import AsyncTrueFoundry, Operation

        client = AsyncTrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.artifact_versions.get_signed_urls(
                id="id",
                paths=["paths"],
                operation=Operation.READ,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_signed_urls(
            id=id, paths=paths, operation=operation, request_options=request_options
        )
        return _response.data

    async def create_multi_part_upload(
        self, *, id: str, path: str, num_parts: int, request_options: typing.Optional[RequestOptions] = None
    ) -> MultiPartUploadResponse:
        """
        Parameters
        ----------
        id : str

        path : str

        num_parts : int

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        MultiPartUploadResponse
            Successful Response

        Examples
        --------
        import asyncio

        from truefoundry_sdk import AsyncTrueFoundry

        client = AsyncTrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.artifact_versions.create_multi_part_upload(
                id="id",
                path="path",
                num_parts=1,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_multi_part_upload(
            id=id, path=path, num_parts=num_parts, request_options=request_options
        )
        return _response.data

    async def stage(
        self, *, manifest: StageArtifactRequestManifest, request_options: typing.Optional[RequestOptions] = None
    ) -> StageArtifactResponse:
        """
        Parameters
        ----------
        manifest : StageArtifactRequestManifest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        StageArtifactResponse
            Successful Response

        Examples
        --------
        import asyncio

        from truefoundry_sdk import (
            AsyncTrueFoundry,
            ModelManifest,
            TrueFoundryManagedSource,
        )

        client = AsyncTrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.artifact_versions.stage(
                manifest=ModelManifest(
                    name="name",
                    metadata={"key": "value"},
                    ml_repo="ml_repo",
                    source=TrueFoundryManagedSource(),
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.stage(manifest=manifest, request_options=request_options)
        return _response.data

    async def list_files(
        self,
        *,
        id: str,
        path: typing.Optional[str] = OMIT,
        limit: typing.Optional[int] = OMIT,
        page_token: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncPager[FileInfo, ListFilesResponse]:
        """
        Parameters
        ----------
        id : str

        path : typing.Optional[str]

        limit : typing.Optional[int]

        page_token : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncPager[FileInfo, ListFilesResponse]
            Successful Response

        Examples
        --------
        import asyncio

        from truefoundry_sdk import AsyncTrueFoundry

        client = AsyncTrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            response = await client.artifact_versions.list_files(
                id="id",
            )
            async for item in response:
                yield item

            # alternatively, you can paginate page-by-page
            async for page in response.iter_pages():
                yield page


        asyncio.run(main())
        """
        return await self._raw_client.list_files(
            id=id, path=path, limit=limit, page_token=page_token, request_options=request_options
        )

    async def mark_stage_failure(
        self, *, id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> EmptyResponse:
        """
        Parameters
        ----------
        id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EmptyResponse
            Successful Response

        Examples
        --------
        import asyncio

        from truefoundry_sdk import AsyncTrueFoundry

        client = AsyncTrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.artifact_versions.mark_stage_failure(
                id="id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.mark_stage_failure(id=id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from .per_thousand_embedding_tokens_cost_metric import PerThousandEmbeddingTokensCostMetric
from .per_thousand_tokens_cost_metric import PerThousandTokensCostMetric
from .public_cost_metric import PublicCostMetric

ModelCostMetric = typing.Union[PerThousandTokensCostMetric, PerThousandEmbeddingTokensCostMetric, PublicCostMetric]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class SparkJobTriggerInput(UniversalBaseModel):
    main_class: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="mainClass")] = pydantic.Field(
        default=None
    )
    """
    Main Class for Spark Job
    """

    main_application_file: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="mainApplicationFile")
    ] = pydantic.Field(default=None)
    """
    Main Application File for Spark Job
    """

    arguments: typing.Optional[str] = pydantic.Field(default=None)
    """
    Arguments to pass to the main application file
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class BaseAutoscaling(UniversalBaseModel):
    min_replicas: int = pydantic.Field(default=1)
    """
    Minimum number of replicas to keep available
    """

    max_replicas: int = pydantic.Field()
    """
    Maximum number of replicas allowed for the component.
    """

    polling_interval: typing.Optional[int] = pydantic.Field(default=30)
    """
    This is the interval to check each trigger on.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .job_run import JobRun


class TriggerJobRunResponse(UniversalBaseModel):
    message: str = pydantic.Field()
    """
    Job triggered
    """

    job_run_name: typing_extensions.Annotated[str, FieldMetadata(alias="jobRunName")] = pydantic.Field()
    """
    Name of the job run
    """

    data: JobRun = pydantic.Field()
    """
    Details of the triggered job run
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .notification_target import NotificationTarget


class WorkflowAlert(UniversalBaseModel):
    """
    Describes the configuration for the workflow alerts
    """

    notification_target: typing.Optional[NotificationTarget] = None
    on_completion: typing.Optional[bool] = pydantic.Field(default=False)
    """
    Send an alert when the job completes
    """

    on_failure: typing.Optional[bool] = pydantic.Field(default=True)
    """
    Send an alert when the job fails
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .policy_mutation_operation import PolicyMutationOperation
from .policy_validation_operation import PolicyValidationOperation

PolicyManifestOperation = typing.Union[PolicyMutationOperation, PolicyValidationOperation]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class Alert(UniversalBaseModel):
    id: typing.Optional[str] = None
    name: str
    timestamps: typing.List[dt.datetime]
    start_time: typing_extensions.Annotated[dt.datetime, FieldMetadata(alias="startTime")]
    resolved_time: typing_extensions.Annotated[typing.Optional[dt.datetime], FieldMetadata(alias="resolvedTime")] = None
    application_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="applicationId")] = None
    cluster_id: typing_extensions.Annotated[str, FieldMetadata(alias="clusterId")]
    tenant_name: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="tenantName")] = None
    fingerprint: str
    updated_at: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="updatedAt")] = None
    created_at: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="createdAt")] = None
    application_debug_info_id: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="applicationDebugInfoId")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class VirtualAccountOwnedBy(UniversalBaseModel):
    """
    Names of the owners that own the virtual account
    """

    account: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the account that owns this resource
    """

    team: str = pydantic.Field()
    """
    The name of the team that owns this resource
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.pagination import AsyncPager, SyncPager
from ..core.request_options import RequestOptions
from ..types.deployment import Deployment
from ..types.get_application_deployment_response import GetApplicationDeploymentResponse
from ..types.list_application_deployments_response import ListApplicationDeploymentsResponse
from .raw_client import AsyncRawApplicationVersionsClient, RawApplicationVersionsClient


class ApplicationVersionsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawApplicationVersionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawApplicationVersionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawApplicationVersionsClient
        """
        return self._raw_client

    def list(
        self,
        id: str,
        *,
        limit: typing.Optional[int] = 100,
        offset: typing.Optional[int] = 0,
        version: typing.Optional[str] = None,
        deployment_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SyncPager[Deployment, ListApplicationDeploymentsResponse]:
        """
        Fetch all deployments for a given application ID with optional filters such as deployment ID or version. Supports pagination.

        Parameters
        ----------
        id : str
            Id of the application

        limit : typing.Optional[int]
            Number of items per page

        offset : typing.Optional[int]
            Number of items to skip

        version : typing.Optional[str]
            Deployment version. Filter deployments by version.

        deployment_id : typing.Optional[str]
            Deployment ID. Filter deployments by a specific ID.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SyncPager[Deployment, ListApplicationDeploymentsResponse]
            List of deployments matching the provided filters.

        Examples
        --------
        from truefoundry_sdk import TrueFoundry

        client = TrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )
        response = client.application_versions.list(
            id="id",
            limit=10,
            offset=0,
            version="1",
            deployment_id="deployment123",
        )
        for item in response:
            yield item
        # alternatively, you can paginate page-by-page
        for page in response.iter_pages():
            yield page
        """
        return self._raw_client.list(
            id,
            limit=limit,
            offset=offset,
            version=version,
            deployment_id=deployment_id,
            request_options=request_options,
        )

    def get(
        self, id: str, deployment_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetApplicationDeploymentResponse:
        """
        Get Deployment associated with the provided application ID and deployment ID.

        Parameters
        ----------
        id : str
            Application id of the application

        deployment_id : str
            Deployment id of the deployment

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetApplicationDeploymentResponse
            Deployment details returned successfully.

        Examples
        --------
        from truefoundry_sdk import TrueFoundry

        client = TrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )
        client.application_versions.get(
            id="id",
            deployment_id="deploymentId",
        )
        """
        _response = self._raw_client.get(id, deployment_id, request_options=request_options)
        return _response.data


class AsyncApplicationVersionsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawApplicationVersionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawApplicationVersionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawApplicationVersionsClient
        """
        return self._raw_client

    async def list(
        self,
        id: str,
        *,
        limit: typing.Optional[int] = 100,
        offset: typing.Optional[int] = 0,
        version: typing.Optional[str] = None,
        deployment_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncPager[Deployment, ListApplicationDeploymentsResponse]:
        """
        Fetch all deployments for a given application ID with optional filters such as deployment ID or version. Supports pagination.

        Parameters
        ----------
        id : str
            Id of the application

        limit : typing.Optional[int]
            Number of items per page

        offset : typing.Optional[int]
            Number of items to skip

        version : typing.Optional[str]
            Deployment version. Filter deployments by version.

        deployment_id : typing.Optional[str]
            Deployment ID. Filter deployments by a specific ID.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncPager[Deployment, ListApplicationDeploymentsResponse]
            List of deployments matching the provided filters.

        Examples
        --------
        import asyncio

        from truefoundry_sdk import AsyncTrueFoundry

        client = AsyncTrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            response = await client.application_versions.list(
                id="id",
                limit=10,
                offset=0,
                version="1",
                deployment_id="deployment123",
            )
            async for item in response:
                yield item

            # alternatively, you can paginate page-by-page
            async for page in response.iter_pages():
                yield page


        asyncio.run(main())
        """
        return await self._raw_client.list(
            id,
            limit=limit,
            offset=offset,
            version=version,
            deployment_id=deployment_id,
            request_options=request_options,
        )

    async def get(
        self, id: str, deployment_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetApplicationDeploymentResponse:
        """
        Get Deployment associated with the provided application ID and deployment ID.

        Parameters
        ----------
        id : str
            Application id of the application

        deployment_id : str
            Deployment id of the deployment

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetApplicationDeploymentResponse
            Deployment details returned successfully.

        Examples
        --------
        import asyncio

        from truefoundry_sdk import AsyncTrueFoundry

        client = AsyncTrueFoundry(
            api_key="YOUR_API_KEY",
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.application_versions.get(
                id="id",
                deployment_id="deploymentId",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(id, deployment_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .chat_prompt_manifest_mcp_servers_item import ChatPromptManifestMcpServersItem
from .chat_prompt_manifest_messages_item import ChatPromptManifestMessagesItem
from .chat_prompt_manifest_response_format import ChatPromptManifestResponseFormat
from .chat_prompt_manifest_routing_config import ChatPromptManifestRoutingConfig
from .guardrails import Guardrails
from .mcp_server_tool_details import McpServerToolDetails
from .model_configuration import ModelConfiguration
from .tool_schema import ToolSchema


class ChatPromptManifest(UniversalBaseModel):
    """
    Chat Prompt manifest.
    """

    name: str = pydantic.Field()
    """
    Name of the entity
    """

    description: typing.Optional[str] = None
    metadata: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Key value metadata. Should be valid JSON. For e.g. `{"business-unit": "sales", "quality": "good", "rating": 4.5}`
    """

    version_alias: typing.Optional[str] = pydantic.Field(default=None)
    """
    Version alias is alternate, ideally human readable, version string to reference an artifact version. It should start with `v` followed by alphanumeric and it can include `.` and `-` in between (e.g. `v1.0.0`, `v1-prod`, `v3-dev`, etc)
    """

    ml_repo: str = pydantic.Field()
    """
    Name of the ML Repo
    """

    version: typing.Optional[int] = pydantic.Field(default=None)
    """
    Version of the entity
    """

    type: typing.Literal["chat_prompt"] = "chat_prompt"
    messages: typing.List[ChatPromptManifestMessagesItem] = pydantic.Field()
    """
    List of messages in the chat conversation, must be non-empty
    """

    variables: typing.Optional[typing.Dict[str, str]] = pydantic.Field(default=None)
    """
    Variables referenced in messages and that can be replaced when running generation
    """

    model_configuration: typing.Optional[ModelConfiguration] = None
    tools: typing.Optional[typing.List[ToolSchema]] = pydantic.Field(default=None)
    """
    List of tools to be used in the chat prompt
    """

    mcp_servers: typing.Optional[typing.List[ChatPromptManifestMcpServersItem]] = pydantic.Field(default=None)
    """
    A list of MCP servers FQNs or URLs and their tools
    """

    guardrails: typing.Optional[Guardrails] = None
    response_format: typing.Optional[ChatPromptManifestResponseFormat] = pydantic.Field(default=None)
    """
    Response format configuration for structured outputs
    """

    routing_config: typing.Optional[ChatPromptManifestRoutingConfig] = pydantic.Field(default=None)
    """
    Configuration for routing requests to different model targets
    """

    tool_call_to_mcp_mapping: typing.Optional[typing.Dict[str, McpServerToolDetails]] = pydantic.Field(default=None)
    """
    Mapping of tool calls to MCP server integration IDs and tool names
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AiFeaturesSettings(UniversalBaseModel):
    """
    Describes the configuration for TrueFoundry AI features
    """

    type: typing.Literal["settings/ai-features"] = pydantic.Field(default="settings/ai-features")
    """
    +value=settings/ai-features
    """

    enabled: bool = pydantic.Field()
    """
    Enable/Disable AI features.
    Other fields only apply when this is true
    """

    ai_provider: typing.Literal["truefoundry"] = pydantic.Field(default="truefoundry")
    """
    AI provider to use for AI features
    When TrueFoundry is selected, TrueFoundry will manage and provide the AI models for the features.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .artifact_manifest_source import ArtifactManifestSource


class ArtifactManifest(UniversalBaseModel):
    """
    Artifact Version manifest.
    """

    name: str = pydantic.Field()
    """
    Name of the entity
    """

    description: typing.Optional[str] = None
    metadata: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Key value metadata. Should be valid JSON. For e.g. `{"business-unit": "sales", "quality": "good", "rating": 4.5}`
    """

    version_alias: typing.Optional[str] = pydantic.Field(default=None)
    """
    Version alias is alternate, ideally human readable, version string to reference an artifact version. It should start with `v` followed by alphanumeric and it can include `.` and `-` in between (e.g. `v1.0.0`, `v1-prod`, `v3-dev`, etc)
    """

    ml_repo: str = pydantic.Field()
    """
    Name of the ML Repo
    """

    version: typing.Optional[int] = pydantic.Field(default=None)
    """
    Version of the entity
    """

    type: typing.Literal["artifact-version"] = "artifact-version"
    source: ArtifactManifestSource
    step: typing.Optional[int] = pydantic.Field(default=0)
    """
    Step/Epoch number in an iterative training loop the artifact version was created. Generally useful when logging a model version from a MLRepo Run
    """

    run_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    ID of the MLRepo Run that generated the artifact version
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AwsSqsAssumedRoleBasedAuth(UniversalBaseModel):
    """
    AWS Assumed Role Based Auth
    """

    type: typing.Literal["assumed-role-based"] = pydantic.Field(default="assumed-role-based")
    """
    +value=assumed-role-based
    """

    assumed_role_arn: str = pydantic.Field()
    """
    ARN of the role you want to assume.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .volume_browser import VolumeBrowser
from .volume_config import VolumeConfig


class Volume(UniversalBaseModel):
    type: typing.Literal["volume"] = pydantic.Field(default="volume")
    """
    +value=volume
    """

    name: str = pydantic.Field()
    """
    Name of the Volume. This will be set as the volume name.
    """

    config: VolumeConfig = pydantic.Field()
    """
    Volume Config - Volume Configuration, can be either Dynamically provisioned or statically provisioned.
    """

    volume_browser: typing.Optional[VolumeBrowser] = None
    workspace_fqn: typing.Optional[str] = pydantic.Field(default=None)
    """
    Fully qualified name of the workspace
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .xg_boost_model_schema import XgBoostModelSchema
from .xg_boost_serialization_format import XgBoostSerializationFormat


class XgBoostFramework(UniversalBaseModel):
    type: typing.Literal["xgboost"] = pydantic.Field(default="xgboost")
    """
    Type of the framework
    """

    serialization_format: typing.Optional[XgBoostSerializationFormat] = None
    model_filepath: typing.Optional[str] = pydantic.Field(default=None)
    """
    Relative path to the model file in the model version contents
    """

    model_schema: typing.Optional[XgBoostModelSchema] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class AlertConfigResourceType(enum.StrEnum):
    """
    The type of resource this alert config belongs to. Can be either an application or a cluster.
    """

    APPLICATION = "application"
    CLUSTER = "cluster"

    def visit(self, application: typing.Callable[[], T_Result], cluster: typing.Callable[[], T_Result]) -> T_Result:
        if self is AlertConfigResourceType.APPLICATION:
            return application()
        if self is AlertConfigResourceType.CLUSTER:
            return cluster()



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .http_probe import HttpProbe


class HealthProbe(UniversalBaseModel):
    """
    Describes the configuration for the Health Probe's
    To learn more you can go [here](https://docs.truefoundry.com/docs/liveness-readiness-probe)
    """

    config: HttpProbe
    initial_delay_seconds: typing.Optional[int] = pydantic.Field(default=0)
    """
    Time to wait after container has started before checking the endpoint
    """

    period_seconds: typing.Optional[int] = pydantic.Field(default=10)
    """
    How often to check the endpoint
    """

    timeout_seconds: typing.Optional[int] = pydantic.Field(default=1)
    """
    Time to wait for a response from the endpoint before considering it down
    """

    success_threshold: typing.Optional[int] = pydantic.Field(default=1)
    """
    Number of successful responses from the endpoint before container is considered healthy
    """

    failure_threshold: typing.Optional[int] = pydantic.Field(default=3)
    """
    Number of consecutive failures before the container is considered down
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .gcp_gcr import GcpGcr
from .gcp_gcs import GcpGcs
from .gcp_gke_integration import GcpGkeIntegration
from .gcp_gsm import GcpGsm

GcpIntegrations = typing.Union[GcpGcr, GcpGcs, GcpGsm, GcpGkeIntegration]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .graph_chart_type import GraphChartType


class Graph(UniversalBaseModel):
    name: str = pydantic.Field()
    """
    Name
    """

    description: str = pydantic.Field()
    """
    Description
    """

    chart: str = pydantic.Field()
    """
    Chart name
    """

    chart_type: typing_extensions.Annotated[GraphChartType, FieldMetadata(alias="chartType")] = pydantic.Field()
    """
    Chart type
    """

    params: str = pydantic.Field()
    """
    Chart params
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class NvidiaTimeslicingGpu(UniversalBaseModel):
    type: typing.Literal["nvidia_timeslicing_gpu"] = pydantic.Field(default="nvidia_timeslicing_gpu")
    """
    +value=nvidia_timeslicing_gpu
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name of the Nvidia GPU. One of [P4, P100, V100, T4, A10G, A100_40GB, A100_80GB]
    This field is required for Node Selector and can be ignored in Nodepool Selector.
    One instance of the card contains the following amount of memory -
    P4: 8 GB, P100: 16 GB, V100: 16 GB, T4: 16 GB, A10G: 24 GB, A100_40GB: 40GB, A100_80GB: 80 GB
    """

    gpu_memory: int = pydantic.Field()
    """
    Amount of GPU memory (in MB) to allocate. Please note, this limit is not being enforced today but will be in future. Applications are expected to operate in co-opertative mode
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .spark_image import SparkImage
from .spark_image_build import SparkImageBuild

SparkJobImage = typing.Union[SparkImage, SparkImageBuild]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .flyte_launch_plan_id import FlyteLaunchPlanId
from .flyte_launch_plan_spec import FlyteLaunchPlanSpec


class FlyteLaunchPlan(UniversalBaseModel):
    id: FlyteLaunchPlanId
    spec: FlyteLaunchPlanSpec
    closure: typing.Any

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .open_ai_moderations_guardrail_config_category_thresholds_value_harassment import (
    OpenAiModerationsGuardrailConfigCategoryThresholdsValueHarassment,
)

OpenAiModerationsGuardrailConfigCategoryThresholdsValue = typing.Union[
    float, OpenAiModerationsGuardrailConfigCategoryThresholdsValueHarassment
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .application_set_components_item import ApplicationSetComponentsItem


class ApplicationSet(UniversalBaseModel):
    """
    Describes the configuration for the application set
    """

    type: typing.Literal["application-set"] = pydantic.Field(default="application-set")
    """
    +value=application-set
    """

    name: str = pydantic.Field()
    """
    Name of the application set.
    """

    components: typing.Optional[typing.List[ApplicationSetComponentsItem]] = pydantic.Field(default=None)
    """
    Array of components with their specifications.
    """

    template: typing.Optional[str] = pydantic.Field(default=None)
    """
    Template to be used for the application set.
    """

    values: typing.Optional[typing.Dict[str, typing.Any]] = pydantic.Field(default=None)
    """
    Values to be used to render components for the application set.
    """

    workspace_fqn: typing.Optional[str] = pydantic.Field(default=None)
    """
    Fully qualified name of the workspace
    """

    convert_template_manifest: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Flag to indicate if the template manifest should be converted to TrueFoundry manifest
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class SklearnSerializationFormat(enum.StrEnum):
    """
    Serialization format used to save the sklearn model
    """

    CLOUDPICKLE = "cloudpickle"
    JOBLIB = "joblib"
    PICKLE = "pickle"

    def visit(
        self,
        cloudpickle: typing.Callable[[], T_Result],
        joblib: typing.Callable[[], T_Result],
        pickle: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is SklearnSerializationFormat.CLOUDPICKLE:
            return cloudpickle()
        if self is SklearnSerializationFormat.JOBLIB:
            return joblib()
        if self is SklearnSerializationFormat.PICKLE:
            return pickle()



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .nvidia_miggpu_profile import NvidiaMiggpuProfile


class NvidiaMiggpu(UniversalBaseModel):
    type: typing.Literal["nvidia_mig_gpu"] = pydantic.Field(default="nvidia_mig_gpu")
    """
    +value=nvidia_mig_gpu
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name of the Nvidia GPU. One of [P4, P100, V100, T4, A10G, A100_40GB, A100_80GB]
    This field is required for Node Selector and can be ignored in Nodepool Selector.
    One instance of the card contains the following amount of memory -
    P4: 8 GB, P100: 16 GB, V100: 16 GB, T4: 16 GB, A10G: 24 GB, A100_40GB: 40GB, A100_80GB: 80 GB
    """

    profile: NvidiaMiggpuProfile = pydantic.Field()
    """
    Name of the MIG profile to use. One of the following based on gpu type
    Please refer to https://docs.nvidia.com/datacenter/tesla/mig-user-guide/#supported-mig-profiles for more details
    A30 - [1g.6gb, 2g.12gb, 4g.24gb]
    A100 40 GB - [1g.5gb, 1g.10gb, 2g.10gb, 3g.20gb, 4g.20gb, 7g.40gb]
    A100 80 GB / H100 80 GB - [1g.10gb, 1g.20gb, 2g.20gb, 3g.40gb, 4g.40gb, 7g.80gb]
    H100 94 GB - [1g.12gb, 1g.24gb, 2g.24gb, 3g.47gb, 4g.47gb, 7g.94gb]
    H100 96 GB - [1g.12gb, 1g.24gb, 2g.24gb, 3g.48gb, 4g.48gb, 7g.96gb]
    H200 141 GB - [1g.18gb, 1g.35gb, 2g.35gb, 3g.71gb, 4g.71gb]
    B200 180 GB - [1g.23gb, 1g.45gb, 2g.45gb, 3g.90gb, 4g.90gb, 7g.180gb]
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow")  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
